@@ -533,7 +533,7 @@ UNIONIMAGESHARED_EXPORT FIBITMAP *readFile2FIBITMAP(const QString &path, int fla
 UNIONIMAGESHARED_EXPORT bool canSave(const QString &path)
 {
     QFileInfo info(path);
-    if (!info.exists()) {
+    if (!info.exists() || !QFile::permissions(path).testFlag(QFile::WriteUser)) {
         return false;
     }
     QImageReader r(path);
@@ -625,29 +625,29 @@ UNIONIMAGESHARED_EXPORT bool loadStaticImageFromFile(const QString &path, QImage
             reader.setFormat(format_bar.toLatin1());
         }
         reader.setAutoTransform(true);
-        if (!reader.canRead() || reader.imageCount() < 1)
-            return false;
-        res_qt = reader.read();
-        if (res_qt.isNull()) {
-            //try old loading method
-            QString format = PrivateDetectImageFormat(path);
-            QImageReader readerF(path, format.toLatin1());
-            QImage try_res;
-            readerF.setAutoTransform(true);
-            if (readerF.canRead() && readerF.imageCount() > 0) {
-                try_res = readerF.read();
-            } else {
-                errorMsg = "can't read image:" + readerF.errorString() + format;
-                try_res = QImage();
+        if (reader.imageCount() > 0 || file_suffix_upper != "ICNS") {
+            res_qt = reader.read();
+            if (res_qt.isNull()) {
+                //try old loading method
+                QString format = PrivateDetectImageFormat(path);
+                QImageReader readerF(path, format.toLatin1());
+                QImage try_res;
+                readerF.setAutoTransform(true);
+                if (readerF.canRead() && readerF.imageCount() > 0) {
+                    try_res = readerF.read();
+                } else {
+                    errorMsg = "can't read image:" + readerF.errorString() + format;
+                    try_res = QImage();
+                }
+                if (try_res.isNull()) {
+                    errorMsg = "load image by qt faild, use format:" + reader.format() + " ,path:" + path;
+                    res = QImage();
+                    return false;
+                }
+                errorMsg = "use old method to load QImage";
+                res = try_res;
+                return true;
             }
-            if (try_res.isNull()) {
-                errorMsg = "load image by qt faild, use format:" + reader.format() + " ,path:" + path;
-                res = QImage();
-                return false;
-            }
-            errorMsg = "use old method to load QImage";
-            res = try_res;
-            return true;
         }
         errorMsg = "use QImage";
         res = res_qt;
@@ -919,7 +919,7 @@ UNIONIMAGESHARED_EXPORT bool rotateImage(int angel, QImage &image)
     return false;
 }
 
-UNIONIMAGESHARED_EXPORT bool rotateImageFIle(int angel, const QString &path, QString &erroMsg)
+UNIONIMAGESHARED_EXPORT bool rotateImageFile(int angel, const QString &path, QString &erroMsg)
 {
     if (angel % 90 != 0) {
         erroMsg = "unsupported angel";
@@ -998,18 +998,21 @@ UNIONIMAGESHARED_EXPORT bool rotateImageFIle(int angel, const QString &path, QSt
     return true;
 }
 
-UNIONIMAGESHARED_EXPORT bool rotateImageFIleWithImage(int angel, QImage &img, const QString &path, QString &erroMsg)
+UNIONIMAGESHARED_EXPORT bool rotateImageFileWithImage(int angel, QImage &img, const QString &path, QString &erroMsg)
 {
+    Q_UNUSED(img)
     if (angel % 90 != 0) {
         erroMsg = "unsupported angel";
         return false;
     }
-    QImage image_copy;
-    if (img.isNull()) return false;
-    else image_copy = img;
 
     QString format = detectImageFormat(path);
     if (format == "SVG") {
+        QImage image_copy;
+        if (!loadStaticImageFromFile(path, image_copy, erroMsg)) {
+            erroMsg = "rotate load QImage faild, path:" + path + "  ,format:+" + format;
+            return false;
+        }
         QSvgGenerator generator;
         generator.setFileName(path);
         generator.setViewBox(QRect(0, 0, image_copy.width(), image_copy.height()));
@@ -1034,15 +1037,16 @@ UNIONIMAGESHARED_EXPORT bool rotateImageFIleWithImage(int angel, QImage &img, co
         generator.setSize(QSize(image_copy.width(), image_copy.height()));
         rotatePainter.end();
         return true;
-    } else if (format == "JPG" || format == "JPEG") {
-        QImage image_copy(path, "JPG");
+    } else if (union_image_private.m_qtrotate.contains(format)) {
+        QPixmap image_copy(path);
         if (!image_copy.isNull()) {
-            QPainter rotatePainter(&image_copy);
-            rotatePainter.rotate(angel);
-            rotatePainter.end();
-            image_copy.save(path, "jpg", SAVE_QUAITY_VALUE);
-            return true;
+            QMatrix rotatematrix;
+            rotatematrix.rotate(angel);
+            image_copy = image_copy.transformed(rotatematrix, Qt::SmoothTransformation);
+            return image_copy.save(path, format.toLatin1().data(), SAVE_QUAITY_VALUE);
         }
+        erroMsg = "rotate by qt failed";
+        return false;
     }
     FIBITMAP *dib = readFile2FIBITMAP(path);
     if (nullptr == dib) {
@@ -1071,7 +1075,7 @@ UNIONIMAGESHARED_EXPORT bool rotateImageFIleWithImage(int angel, QImage &img, co
         FreeImage_Unload(rotateRes);
         return false;
     }
-    img = FIBitmap2QImage(rotateRes);
+
     if (!writeFIBITMAPToFile(rotateRes, path, f)) {
         erroMsg = "rotate image save faild, unkown format";
         FreeImage_Unload(dib);
