@@ -270,14 +270,13 @@ void ImgInfoDialog::updateBaseInfo(const QMap<QString, QString> &infos)
     clearLayout(m_exifLayout_base);
 
     for (MetaData *i = MetaDataBasics; ! i->key.isEmpty(); i ++) {
-        QString key = i->key;
         QString value = infos.value(i->key);
         if (i->key.contains("Dimension")) {
             value = infos.value("Dimension");
             if (value == "0x0") {
-                ImageDataSt st;
+                DBImgInfo st;
                 ImageEngineApi::instance()->getImageData(m_path, st);
-                value = st.dbi.albumSize;
+                value = st.albumSize;
                 if (value.isEmpty()) {
                     QImage tImg;
                     QString errMsg;
@@ -431,7 +430,7 @@ int ImgInfoDialog::contentHeight() const
 void ImgInfoDialog::keyPressEvent(QKeyEvent *e)
 {
     if (e->key() == Qt::Key_Escape) {
-        emit closed();
+        this->close();
     }
     DDialog::keyPressEvent(e);
 }
@@ -447,7 +446,6 @@ void ImgInfoDialog::paintEvent(QPaintEvent *event)
     DDialog::paintEvent(event);
 }
 
-
 bool ImgInfoDialog::event(QEvent *event)
 {
     if (event->type() == QEvent::ActivationChange) {
