@@ -37,7 +37,9 @@
 #include "signalmanager.h"
 #include "../test_qtestDefine.h"
 #include "ac-desktop-define.h"
-
+#include "testtoolkits.h"
+#include "batchoperatewidget.h"
+#include "imagedataservice.h"
 
 TEST(allpicview, test_ini)
 {
@@ -157,79 +159,6 @@ TEST(allpicview, mousePress)
     QTest::qWait(500);
 }
 
-TEST(allpicview, test_open)
-{
-    TEST_CASE_NAME("test_open");
-
-    QString publicTestPath = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + QDir::separator() + "test";
-    QString testPath = publicTestPath;
-    MainWindow *w = dApp->getMainWindow();
-    QStringList testPathlist = ImageEngineApi::instance()->get_AllImagePath();
-    if (!testPathlist.isEmpty()) {
-        ImageEngineApi::instance()->moveImagesToTrash(testPathlist);
-        QTest::qWait(500);
-    }
-    AllPicView *a = w->m_pAllPicView;
-    QTestEventList tl;
-    tl.addMouseMove(QPoint(0, 0), 100);
-    tl.addMousePress(Qt::MouseButton::LeftButton, Qt::KeyboardModifier::NoModifier, QPoint(0, 0), 100);
-    tl.addMouseMove(a->m_pImportView->geometry().center());
-    tl.simulate(a->m_pImportView);
-    ImageEngineApi::instance()->ImportImagesFromFileList((QStringList() << testPath), "", a, false);
-    QTest::qWait(500);
-
-    testPathlist = ImageEngineApi::instance()->get_AllImagePath();
-    if (!testPathlist.isEmpty()) {
-        qDebug() << "test ImageView Success ";
-        w->m_pSearchEdit->setText("1");
-        w->m_pSearchEdit->editingFinished();
-        QTest::qWait(300);
-        emit a->getThumbnailListView()->menuOpenImage(testPathlist.first(), testPathlist, false);
-        QTest::qWait(300);
-        QTestEventList e;
-        e.addKeyClick(Qt::Key_Minus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Minus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Plus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Plus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Plus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Plus, Qt::ControlModifier, 100);
-        e.addKeyClick(Qt::Key_Plus, Qt::ControlModifier, 100);
-        e.simulate(w);
-        e.clear();
-
-        emit dApp->signalM->showImageInfo(testPathlist.first());
-
-        CommandLine *commandline = CommandLine::instance();
-        QString jpgItemPath = testPath_test + "/2e5y8y.jpg";
-        QStringList list;
-        list << jpgItemPath;
-        commandline->viewImage(jpgItemPath, list);
-
-        MainWidget *mw = CommandLine::instance()->findChild<MainWidget *>("MainWidget");
-        if (mw) {
-            TTBContent *t = mw->findChild<TTBContent *>("TTBContent");
-            if (t) {
-                MyImageListWidget *ml = t->findChild<MyImageListWidget *>("MyImageListWidget");
-                if (ml) {
-                    ml->getObj();
-                    ml->findSelectItem();
-                    ml->thumbnailIsMoving();
-                    ml->stopAnimation();
-                    ml->deleteLater();
-                }
-            }
-        }
-    }
-    QTest::qWait(500);
-    QTestEventList e;
-    e.addKeyClick(Qt::Key_Escape);
-    e.simulate(w);
-
-    ImgDeleteDialog *dialog = new ImgDeleteDialog(a->getThumbnailListView(), testPathlist.length());
-    ImageEngineApi::instance()->moveImagesToTrash(testPathlist, true, false);
-    dialog->deleteLater();
-}
-
 TEST(allpicview, test_select)
 {
     TEST_CASE_NAME("test_select")
@@ -247,26 +176,77 @@ TEST(allpicview, test_select)
 
     dApp->signalM->sigShortcutKeyDelete();
     QTest::qWait(100);
-    a->getThumbnailListView()->sigLoad80ThumbnailsFinish();
+//    a->getThumbnailListView()->sigLoad80ThumbnailsFinish();
     QTest::qWait(100);
     a->updateStackedWidget();
     a->restorePicNum();
     a->updatePicNum();
     dApp->signalM->imagesRemoved();
     QTest::qWait(100);
-    a->getThumbnailListView()->openImage(0);
-    QTest::qWait(100);
+//    emit a->getThumbnailListView()->openImage(0, ImageEngineApi::instance()->get_AllImagePath().first(), false);
+//    QTest::qWait(100);
 }
 
-TEST(allpicview, test_shortCut)
+TEST(allpicview, BatchOperateWidget)
 {
-    TEST_CASE_NAME("test_shortCut")
-    MainWindow *w = dApp->getMainWindow();
-    w->createShorcutJson();
+    TEST_CASE_NAME("BatchOperateWidget")
+
+    if (ImageEngineApi::instance()->getAllImageDataCount() <= 0) {
+        return;
+    }
+    //定位到所有图片
+    clickToAllPictureView();
+    //定位到第一张图片位置
+    QModelIndex index;
+    for (int i = 0; i < dApp->getMainWindow()->m_pAllPicView->getThumbnailListView()->m_model->rowCount(); i++) {
+        index = dApp->getMainWindow()->m_pAllPicView->getThumbnailListView()->m_model->index(i, 0);
+        DBImgInfo data = index.data(Qt::DisplayRole).value<DBImgInfo>();
+        if (data.itemType == ItemType::ItemTypePic) {
+            break;
+        }
+    }
+    QRect picItem = dApp->getMainWindow()->m_pAllPicView->getThumbnailListView()->visualRect(index);
+    //选中第一张图片
+    QTest::qWait(200);
+    QPoint p1(picItem.x() + 20, picItem.y() + 20);
     QTestEventList e;
-    e.addKeyClick(Qt::Key_Question, Qt::ControlModifier | Qt::ShiftModifier);
-    e.simulate(w);
-    QTest::qWait(500);
+    e.addMouseMove(p1);
+    e.addMouseClick(Qt::MouseButton::LeftButton, Qt::NoModifier, p1, 50);
+    e.simulate(dApp->getMainWindow()->m_pAllPicView->m_pThumbnailListView->viewport());
+    e.clear();
+    QTest::qWait(200);
+
+    BatchOperateWidget *batchOperateWidget = dApp->getMainWindow()->m_pAllPicView->findChild<BatchOperateWidget *>(All_Picture_BatchOperateWidget);
+    if (batchOperateWidget) {
+        batchOperateWidget->sltCollectSelect(true);
+        QTest::qWait(200);
+        batchOperateWidget->sltCollectSelect(true);
+        QTest::qWait(200);
+        batchOperateWidget->sltRightRotate(true);
+        QTest::qWait(200);
+        batchOperateWidget->sltLeftRotate(true);
+        QTest::qWait(200);
+        batchOperateWidget->sltSelectAll();
+        QTest::qWait(200);
+        batchOperateWidget->sltUnSelectAll();
+    }
+
+    dApp->getMainWindow()->m_pAllPicView->m_pThumbnailListView->clearSelection();
+    if (batchOperateWidget) {
+        ExpansionPanel::FilteData data;
+
+        data.type = ItemType::ItemTypeNull;
+        batchOperateWidget->sltCurrentFilterChanged(data);
+        QTest::qWait(200);
+
+        data.type = ItemType::ItemTypePic;
+        batchOperateWidget->sltCurrentFilterChanged(data);
+        QTest::qWait(200);
+
+        data.type = ItemType::ItemTypeVideo;
+        batchOperateWidget->sltCurrentFilterChanged(data);
+        QTest::qWait(200);
+    }
 }
 
 TEST(allpicview, test_showInFileManagerAndBackGrond)
@@ -330,7 +310,7 @@ TEST(allpicview, viewpaneltest)
         w->m_pSearchEdit->editingFinished();
         QTest::qWait(300);
 
-        emit a->getThumbnailListView()->menuOpenImage(testPathlist.first(), testPathlist, false);
+        emit a->getThumbnailListView()->openImage(0, testPathlist.first(), false);
         QTest::qWait(300);
 
         QTestEventList e;
@@ -344,7 +324,7 @@ TEST(allpicview, viewpaneltest)
         e.simulate(w);
         e.clear();
 
-        emit dApp->signalM->showImageInfo(testPathlist.first());
+//        emit dApp->signalM->showImageInfo(testPathlist.first());
 
         QTest::qWait(500);
 //        ImgInfoDialog *dialog = w->findChild<ImgInfoDialog *>("ImgInfoDialog");
@@ -379,7 +359,7 @@ TEST(allpicview, viewpaneltest)
                 QTest::qWait(100);
                 viewPanel->onHideImageView();
                 QTest::qWait(500);
-                emit a->getThumbnailListView()->menuOpenImage(testPathlist.first(), testPathlist, false);
+                emit a->getThumbnailListView()->openImage(0, testPathlist.first(), false);
                 QTest::qWait(500);
 //                viewPanel->onESCKeyActivated();
 //                QTest::qWait(500);
@@ -400,64 +380,10 @@ TEST(allpicview, viewpaneltest)
             t->updateFilenameLayout();
             QTest::qWait(500);
 
-            DWidget *imgList = t->findChild<DWidget *>("imageListObj");
-            if (imgList) {
-                QObjectList list = dynamic_cast<DWidget *>(imgList)->children();
-                for (int i = 0; i < list.size(); i++) {
-                    QList<ImageItem *> labelList = dynamic_cast<DWidget *>(imgList)->findChildren<ImageItem *>(QString("%1").arg(i));
-                    if (labelList.size() <= 0) {
-                        continue;
-                    }
-                    ImageItem *img = labelList.at(0);
-                    if (nullptr == img) {
-                        continue;
-                    }
-                    img->emitClickSig();
-                    QTest::qWait(400);
-                }
-            }
-
-            MyImageListWidget *imgListView = t->findChild<MyImageListWidget *>("MyImageListWidget");
-            if (imgListView) {
-                imgListView->animationFinished();
-                imgListView->findSelectItem();
-                imgListView->animationStart(true, 0, 300);
-                imgListView->stopAnimation();
-//                imgListView->isAnimationStart();
-//                imgListView->animationTimerTimeOut();
-            }
-
-            QTestEventList el;
-            QPoint p(150, 20);
-            el.addMouseMove(p);
-            el.addMousePress(Qt::MouseButton::LeftButton, Qt::KeyboardModifier::NoModifier, p, 100);
-            p = p + QPoint(-20, 0);
-            el.addMouseMove(p, 100);
-//            QTest::qWait(300);
-            p = p + QPoint(-20, 0);
-            el.addMouseMove(p, 100);
-//            QTest::qWait(300);
-            p = p + QPoint(-20, 0);
-            el.addMouseMove(p, 100);
-//            QTest::qWait(300);
-            p = p + QPoint(-20, 0);
-            el.addMouseMove(p, 100);
-//            QTest::qWait(300);
-            p = p + QPoint(-20, 0);
-            el.addMouseMove(p, 100);
-//            QTest::qWait(300);
-            el.addMouseRelease(Qt::LeftButton, Qt::NoModifier, p, 100);
-            el.simulate(imgList);
-            el.clear();
-
-            if (imgListView) {
-                QPoint p2(imgListView->pos().x() - 50, imgListView->pos().y() + 10);
-                el.addMouseMove(p2);
-                el.addMousePress(Qt::MouseButton::LeftButton, Qt::KeyboardModifier::NoModifier, p2, 100);
-                el.addMouseMove(QPoint(p2.x() + 100, p2.y()), 100);
-                el.addMouseRelease(Qt::LeftButton, Qt::NoModifier, QPoint(p2.x() + 100, p2.y()), 100);
-                el.simulate(imgListView);
-            }
+            //todo
+//            MyImageListWidget *imgListView = t->findChild<MyImageListWidget *>("MyImageListWidget");
+//            if (imgListView) {
+//            }
         }
     }
 
@@ -477,11 +403,11 @@ TEST(allpicview, deleteTips)
     if (testPathlist.count() > 0) {
         QStringList tempDel;
         tempDel << testPathlist.last();
-        ImgDeleteDialog *delDlg = new ImgDeleteDialog(a->getThumbnailListView(), tempDel.length());
-        delDlg->show();
-        QTest::qWait(500);
+//        ImgDeleteDialog *delDlg = new ImgDeleteDialog(a->getThumbnailListView(), tempDel.length());
+//        delDlg->show();
+//        QTest::qWait(500);
         ImageEngineApi::instance()->moveImagesToTrash(tempDel);
-        delDlg->deleteLater();
+//        delDlg->deleteLater();
         QTest::qWait(500);
     }
 }
@@ -491,8 +417,7 @@ TEST(allpicview, allpicview_other_test)
     TEST_CASE_NAME("allpicview_other_test")
     MainWindow *w = dApp->getMainWindow();
 
-    w->m_pAllPicView->onFinishLoad();
-    w->m_pAllPicView->onMenuOpenImage("", QStringList(), false, false);
+//    w->m_pAllPicView->onMenuOpenImage("", QStringList(), false, false);
 //    w->m_pAllPicView->onImportViewImportBtnClicked();
 
 
