@@ -7,7 +7,7 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Zrušit</translation>
+        <translation>Storno</translation>
     </message>
     <message>
         <source>Create</source>
@@ -22,7 +22,7 @@
     <name>AlbumDeleteDialog</name>
     <message>
         <source>Cancel</source>
-        <translation>Zrušit</translation>
+        <translation>Storno</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -58,14 +58,6 @@
         <source>Favorites</source>
         <translation>Oblíbené</translation>
     </message>
-    <message>
-        <source>Delete All</source>
-        <translation>Smazat vše</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Smazat</translation>
-    </message>
     <message>
         <source>Or drag photos here</source>
         <translation>Nebo fotky přetáhněte sem</translation>
@@ -78,38 +70,14 @@
         <source>Import All</source>
         <translation>Importovat vše</translation>
     </message>
-    <message>
-        <source>The photos will be permanently deleted after the days shown on it</source>
-        <translation>Po uplynutí počtu dnů na tomto zobrazených budou fotky nadobro smazány</translation>
-    </message>
-    <message>
-        <source>Restore</source>
-        <translation>Obnovit</translation>
-    </message>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>vybráno %1 fotek</translation>
-    </message>
     <message>
         <source>Import to:</source>
         <translation>Importovat do:</translation>
     </message>
-    <message>
-        <source>Disk</source>
-        <translation type="vanished">Disk</translation>
-    </message>
     <message>
         <source>Import</source>
         <translation>Import</translation>
     </message>
-    <message>
-        <source>days</source>
-        <translation type="vanished">dní</translation>
-    </message>
-    <message>
-        <source>Unnamed</source>
-        <translation type="vanished">Nepojmenované</translation>
-    </message>
     <message>
         <source>System Disk</source>
         <translation>Systémový disk</translation>
@@ -139,19 +107,12 @@
         <translation>Ignorovat</translation>
     </message>
     <message>
-        <source>Loading photos, please wait...</source>
-        <translation>Načítání fotek – čekejte prosím…</translation>
-    </message>
-</context>
-<context>
-    <name>AllPicView</name>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>Vybráno %1 fotek</translation>
+        <source>Loading...</source>
+        <translation>Načítání</translation>
     </message>
     <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 fotek</translation>
+        <source>The files will be permanently deleted after the days shown on it</source>
+        <translation>Po uplynutí počtu dnů na tomto zobrazených budou soubory nadobro smazány</translation>
     </message>
 </context>
 <context>
@@ -165,7 +126,7 @@
     <name>CExportImageDialog</name>
     <message>
         <source>Cancel</source>
-        <translation>Zrušit</translation>
+        <translation>Storno</translation>
     </message>
     <message>
         <source>Replace</source>
@@ -254,10 +215,6 @@
         <source>%1 Encrypted</source>
         <translation>%1 zašifrováno</translation>
     </message>
-    <message>
-        <source>%1 </source>
-        <translation type="vanished">%1 </translation>
-    </message>
     <message>
         <source>%1 Volume</source>
         <translation>%1 svazek</translation>
@@ -275,7 +232,7 @@
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Zrušit</translation>
+        <translation>Storno</translation>
     </message>
 </context>
 <context>
@@ -291,50 +248,10 @@
         <source>Deleting...</source>
         <translation>Mazání…</translation>
     </message>
-    <message>
-        <source>Importing...</source>
-        <translation>Importování…</translation>
-    </message>
     <message>
         <source>Restoring...</source>
         <translation>Obnovování…</translation>
     </message>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerie</translation>
-    </message>
-</context>
-<context>
-    <name>ImageImportFilesFromMountThread</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerie</translation>
-    </message>
-</context>
-<context>
-    <name>ImageInfoWidget</name>
-    <message>
-        <source>Basic info</source>
-        <translation type="vanished">Základní údaje</translation>
-    </message>
-    <message>
-        <source>Details</source>
-        <translation type="vanished">Podrobnosti</translation>
-    </message>
-</context>
-<context>
-    <name>ImageLoadFromLocalThread</name>
-    <message>
-        <source>days</source>
-        <translation>dní</translation>
-    </message>
-</context>
-<context>
-    <name>ImageLoader</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerie</translation>
-    </message>
 </context>
 <context>
     <name>ImgDeleteDialog</name>
@@ -350,9 +267,21 @@
         <source>Are you sure you want to delete this photo from the album?</source>
         <translation>Opravdu chcete tuto fotku vymazat z alba?</translation>
     </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n photos from albums?</source>
+        <translation><numerusform>Opravdu chcete %n fotku vymazat z alb?</numerusform><numerusform>Opravdu chcete %n fotky vymazat z alb?</numerusform><numerusform>Opravdu chcete %n fotek vymazat z alb?</numerusform><numerusform>Opravdu chcete %n fotky vymazat z alb?</numerusform></translation>
+    </message>
     <message>
-        <source>Are you sure you want to delete %1 photos from albums?</source>
-        <translation>Opravdu chcete %1 fotek vymazat z alb?</translation>
+        <source>Are you sure you want to delete this video from the album?</source>
+        <translation>Opravdu chcete toto video vymazat z alba?</translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n videos from albums?</source>
+        <translation><numerusform>Opravdu chcete %n video vymazat z alb?</numerusform><numerusform>Opravdu chcete %n videa vymazat z alb?</numerusform><numerusform>Opravdu chcete %n videí vymazat z alb?</numerusform><numerusform>Opravdu chcete %n videa vymazat z alb?</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n items from albums?</source>
+        <translation><numerusform>Opravdu chcete %n položku vymazat z alb?</numerusform><numerusform>Opravdu chcete %n položky vymazat z alb?</numerusform><numerusform>Opravdu chcete %n položek vymazat z alb?</numerusform><numerusform>Opravdu chcete %n položky vymazat z alb?</numerusform></translation>
     </message>
 </context>
 <context>
@@ -370,37 +299,46 @@
         <translation>Informace o fotce</translation>
     </message>
 </context>
-<context>
-    <name>ImportImagesThread</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerie</translation>
-    </message>
-</context>
 <context>
     <name>ImportTimeLineView</name>
     <message>
         <source>Import</source>
         <translation>Importovat</translation>
     </message>
+    <message>
+        <source>1 photo</source>
+        <translation>1 fotka</translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation>1 video</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n fotka</numerusform><numerusform>%n fotky</numerusform><numerusform>%n fotek</numerusform><numerusform>%n fotky</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n video</numerusform><numerusform>%n videa</numerusform><numerusform>%n videí</numerusform><numerusform>%n videa</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items</source>
+        <translation><numerusform>%n položka</numerusform><numerusform>%n položky</numerusform><numerusform>%n položek</numerusform><numerusform>%n položky</numerusform></translation>
+    </message>
 </context>
 <context>
     <name>ImportView</name>
     <message>
-        <source>All Photos</source>
-        <translation>Všechny fotky</translation>
+        <source>Import Photos and Videos</source>
+        <translation>Importovat fotky a videa</translation>
     </message>
     <message>
-        <source>Import Photos</source>
-        <translation>Importovat fotky</translation>
+        <source>Or drag them here</source>
+        <translation>Nebo je přetáhněte sem</translation>
     </message>
     <message>
-        <source>Or drag photos here</source>
-        <translation>Nebo fotky přetáhněte sem</translation>
-    </message>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerie</translation>
+        <source>All photos and videos</source>
+        <translation>Všechny fotky a videa</translation>
     </message>
 </context>
 <context>
@@ -421,10 +359,6 @@
         <source>Delete</source>
         <translation>Smazat</translation>
     </message>
-    <message>
-        <source>Unnamed</source>
-        <translation type="vanished">Nepojmenovaný</translation>
-    </message>
     <message>
         <source>Device</source>
         <translation>Zařízení</translation>
@@ -445,15 +379,15 @@
 <context>
     <name>LockWidget</name>
     <message>
-        <source>You have no permission to view the image</source>
-        <translation>Nemáte oprávnění zobrazit obrázek</translation>
+        <source>You have no permission to view the file</source>
+        <translation>Nemáte oprávnění zobrazit obsah souboru</translation>
     </message>
 </context>
 <context>
     <name>Main</name>
     <message>
-        <source>Album is a fashion photo manager for viewing and organizing pictures.</source>
-        <translation>Album je šikovný správce fotek pro zobrazování a uspořádávání obrázků.</translation>
+        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
+        <translation>Album je šikovný správce pro zobrazování a uspořádávání fotek a videí</translation>
     </message>
 </context>
 <context>
@@ -550,14 +484,6 @@
         <source>Albums</source>
         <translation>Alba</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation type="vanished">%1 fotek</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Informace o fotce</translation>
-    </message>
     <message>
         <source>Exit fullscreen/slideshow</source>
         <translation>Opustit celou obrazovku/promítání</translation>
@@ -570,22 +496,10 @@
         <source>View</source>
         <translation>Pohled</translation>
     </message>
-    <message>
-        <source>Export</source>
-        <translation>Exportovat</translation>
-    </message>
-    <message>
-        <source>Import</source>
-        <translation>Importovat</translation>
-    </message>
     <message>
         <source>Select all</source>
         <translation>Vybrat vše</translation>
     </message>
-    <message>
-        <source>Delete photo/album</source>
-        <translation>Smazat fotku/album</translation>
-    </message>
     <message>
         <source>Zoom in</source>
         <translation>Přiblížit</translation>
@@ -610,36 +524,40 @@
         <source>Settings</source>
         <translation>Nastavení</translation>
     </message>
-    <message>
-        <source>Some photos have not been imported</source>
-        <translation type="vanished">Některé fotky nebyly naimportovány</translation>
-    </message>
     <message>
         <source>Import photos</source>
         <translation>Importovat fotky</translation>
     </message>
-    <message>
-        <source>Import Photos</source>
-        <translation>Import fotek</translation>
-    </message>
-    <message>
-        <source>%1/%2 photos imported</source>
-        <translation>Naimportováno %1/%2 fotek</translation>
-    </message>
-    <message>
-        <source>%1 photos imported, %2 photos failed</source>
-        <translation>Naimportováno %1 fotek, nepodařilo se u %2 fotek</translation>
-    </message>
-    <message>
-        <source>%1/%2 photos deleted</source>
-        <translation>Smazáno %1/%2 fotek</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Importování…</translation>
     </message>
     <message>
-        <source>Photos already exist</source>
+        <source>All photos and videos</source>
+        <translation>Všechny fotky a videa</translation>
+    </message>
+    <message>
+        <source>Import Photos and Videos</source>
+        <translation>Importovat fotky a videa</translation>
+    </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Nenalezeny žádné fotky či videa</translation>
+    </message>
+    <message>
+        <source>Export photos</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import photos/videos</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Smazat</translation>
+    </message>
+    <message>
+        <source>Photo/Video info</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -731,78 +649,10 @@
     </message>
 </context>
 <context>
-    <name>MountThumbnailListView</name>
+    <name>NoResultWidget</name>
     <message>
-        <source>Photo info</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>View</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Restore</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Add to album</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation type="unfinished"/>
+        <source>No results</source>
+        <translation>Nic nenalezeno</translation>
     </message>
 </context>
 <context>
@@ -812,56 +662,6 @@
         <translation>Systémový disk</translation>
     </message>
 </context>
-<context>
-    <name>PrintOptionsPage</name>
-    <message>
-        <source>No scaling</source>
-        <translation type="vanished">Žádná změna velikosti</translation>
-    </message>
-    <message>
-        <source>Fit page to image</source>
-        <translation type="vanished">Přizpůsobit stránku obrázku</translation>
-    </message>
-    <message>
-        <source>Fit image to page</source>
-        <translation type="vanished">Přizpůsobit obrázek na stránku</translation>
-    </message>
-    <message>
-        <source>Scale to:</source>
-        <translation type="vanished">Změnit velikost na:</translation>
-    </message>
-    <message>
-        <source>Millimeters</source>
-        <translation type="vanished">Milimetry</translation>
-    </message>
-    <message>
-        <source>Centimeters</source>
-        <translation type="vanished">Centimetry</translation>
-    </message>
-    <message>
-        <source>Inches</source>
-        <translation type="vanished">Palce</translation>
-    </message>
-    <message>
-        <source>Image Position</source>
-        <translation type="vanished">Pozice obrázku</translation>
-    </message>
-    <message>
-        <source>Scaling</source>
-        <translation type="vanished">Změna velikosti</translation>
-    </message>
-    <message>
-        <source>Image Settings</source>
-        <translation type="vanished">Nastavení obrázku</translation>
-    </message>
-</context>
-<context>
-    <name>PrintPreviewDialog</name>
-    <message>
-        <source>Image Settings</source>
-        <translation type="vanished">Nastavení obrázku</translation>
-    </message>
-</context>
 <context>
     <name>QObject</name>
     <message>
@@ -876,22 +676,6 @@
         <source>%1/%2/%3</source>
         <translation>%1/%2/%3</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 fotek</translation>
-    </message>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>Vybráno %1 fotek</translation>
-    </message>
-    <message>
-        <source>%1/%2/%3 %4</source>
-        <translation type="vanished">%1/%2/%3 %4</translation>
-    </message>
-    <message>
-        <source>Import on </source>
-        <translation type="vanished">Importováno</translation>
-    </message>
     <message>
         <source>Imported on</source>
         <translation>Importováno </translation>
@@ -904,6 +688,98 @@
         <source>Imported on </source>
         <translation>Okamžik importu</translation>
     </message>
+    <message>
+        <source>Select All</source>
+        <translation>Vybrat vše</translation>
+    </message>
+    <message>
+        <source>Unselect All</source>
+        <translation>Zrušit výběr všeho</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Zrušit</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation>Obnovit</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Smazat</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Vše</translation>
+    </message>
+    <message>
+        <source>Photos</source>
+        <translation>Fotky</translation>
+    </message>
+    <message>
+        <source>Videos</source>
+        <translation>Videa</translation>
+    </message>
+    <message>
+        <source>No results</source>
+        <translation>Nic nenalezeno</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation>Přidat do oblíbených</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation>Otočit doleva</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation>Otočit doprava</translation>
+    </message>
+    <message>
+        <source>Importing...</source>
+        <translation>Importování…</translation>
+    </message>
+    <message>
+        <source>%1/%2 items imported</source>
+        <translation>Naimportováno %1/%2 položek</translation>
+    </message>
+    <message>
+        <source>%1/%2 items deleted</source>
+        <translation>Smazáno %1/%2 položek</translation>
+    </message>
+    <message>
+        <source>%1 items imported, %2 items failed</source>
+        <translation>Naimportováno %1 položek, nepodařilo se u %2 položek</translation>
+    </message>
+    <message>
+        <source>1 photo selected</source>
+        <translation>Vybrána 1 fotka</translation>
+    </message>
+    <message>
+        <source>1 video selected</source>
+        <translation>Vybráno 1 video</translation>
+    </message>
+    <message>
+        <source>The photo/video already exists</source>
+        <translation>Fotka/video už existuje</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos selected</source>
+        <translation><numerusform>Vybrána %n fotka</numerusform><numerusform>Vybrány %n fotky</numerusform><numerusform>Vybráno %n fotek</numerusform><numerusform>Vybrány %n fotky</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos selected</source>
+        <translation><numerusform>Vybráno %n video</numerusform><numerusform>Vybrána %n videa</numerusform><numerusform>Vybráno %n videí</numerusform><numerusform>Vybrána %n videa</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items selected</source>
+        <translation><numerusform>Vybrána %n položka</numerusform><numerusform>Vybrány %n položky</numerusform><numerusform>Vybráno %n položek</numerusform><numerusform>Vybrány %n položky</numerusform></translation>
+    </message>
+    <message>
+        <source>%1 items imported, %2 items exist already</source>
+        <translation>Naimportování %1 položek, %2 položek už existuje</translation>
+    </message>
 </context>
 <context>
     <name>SearchView</name>
@@ -915,14 +791,30 @@
         <source>Slide Show</source>
         <translation>Promítání</translation>
     </message>
-    <message>
-        <source>%1 photo(s) found</source>
-        <translation>Nalezeno %1 fotek</translation>
-    </message>
     <message>
         <source>Search results</source>
         <translation>Výsledky hledání</translation>
     </message>
+    <message>
+        <source>1 photo found</source>
+        <translation>Nalezena 1 fotka</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos found</source>
+        <translation><numerusform>nalezeno %n video</numerusform><numerusform>nalezena %n videa</numerusform><numerusform>nalezeno %n videí</numerusform><numerusform>nalezena %n videa</numerusform></translation>
+    </message>
+    <message>
+        <source>1 video found</source>
+        <translation>Nalezeno 1 video</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items found</source>
+        <translation><numerusform>nalezena %n položka</numerusform><numerusform>nalezeny %n položky</numerusform><numerusform>nalezeno %n položek</numerusform><numerusform>nalezeny %n položky</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos found</source>
+        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+    </message>
 </context>
 <context>
     <name>SlideShowBottomBar</name>
@@ -950,12 +842,28 @@
 <context>
     <name>StatusBar</name>
     <message>
-        <source>Importing photos: &apos;%1&apos;</source>
-        <translation>Import fotek: „%1“</translation>
+        <source>1 photo</source>
+        <translation>1 fotka</translation>
     </message>
     <message>
-        <source>Exporting photos: &apos;%1&apos;</source>
-        <translation>Export fotek: „%1“</translation>
+        <source>1 video</source>
+        <translation>1 video</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n fotka</numerusform><numerusform>%n fotky</numerusform><numerusform>%n fotek</numerusform><numerusform>%n fotky</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n video</numerusform><numerusform>%n videa</numerusform><numerusform>%n videí</numerusform><numerusform>%n video</numerusform></translation>
+    </message>
+    <message>
+        <source>Importing: %1</source>
+        <translation>Importuje se: %1</translation>
+    </message>
+    <message>
+        <source>Exporting: %1</source>
+        <translation>Exportuje se: %1</translation>
     </message>
 </context>
 <context>
@@ -1075,6 +983,14 @@
         <source>Print</source>
         <translation>Tisk</translation>
     </message>
+    <message>
+        <source>Video info</source>
+        <translation>Informace o videu</translation>
+    </message>
+    <message>
+        <source>days</source>
+        <translation>dní</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -1087,6 +1003,120 @@
         <translation>Fotka nenalezena</translation>
     </message>
 </context>
+<context>
+    <name>TimeLineView</name>
+    <message>
+        <source>1 photo</source>
+        <translation>1 fotka</translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation>1 video</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n fotka</numerusform><numerusform>%n fotky</numerusform><numerusform>%n fotek</numerusform><numerusform>%n fotky</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n video</numerusform><numerusform>%n videa</numerusform><numerusform>%n videí</numerusform><numerusform>%n videa</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items</source>
+        <translation><numerusform>%n položka</numerusform><numerusform>%n položky</numerusform><numerusform>%n položek</numerusform><numerusform>%n položky</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>VideoInfoDialog</name>
+    <message>
+        <source>Basic info</source>
+        <translation>Základní údaje</translation>
+    </message>
+    <message>
+        <source>Codec info</source>
+        <translation>Informace o kodeku</translation>
+    </message>
+    <message>
+        <source>Audio info</source>
+        <translation>Informace o zvuku</translation>
+    </message>
+    <message>
+        <source>Video CodecID</source>
+        <translation>Identifikátor kodeku videa</translation>
+    </message>
+    <message>
+        <source>Video CodeRate</source>
+        <translation>Bitová rychlost kodeku videa</translation>
+    </message>
+    <message>
+        <source>FPS</source>
+        <translation>SN/S</translation>
+    </message>
+    <message>
+        <source>Proportion</source>
+        <translation>Proporce</translation>
+    </message>
+    <message>
+        <source>Resolution</source>
+        <translation>Rozlišení</translation>
+    </message>
+    <message>
+        <source>Audio CodecID</source>
+        <translation>Identifikátor kodeku zvuku</translation>
+    </message>
+    <message>
+        <source>Audio CodeRate</source>
+        <translation>Bitová rychlost kodeku zvuku</translation>
+    </message>
+    <message>
+        <source>Audio digit</source>
+        <translation>Zvuk digit</translation>
+    </message>
+    <message>
+        <source>Channels</source>
+        <translation>Kanály</translation>
+    </message>
+    <message>
+        <source>Channel</source>
+        <translation>Kanál</translation>
+    </message>
+    <message>
+        <source>Sampling</source>
+        <translation>Frekvence vzorkování</translation>
+    </message>
+    <message>
+        <source>Video name</source>
+        <translation>Název videa</translation>
+    </message>
+    <message>
+        <source>Date modified</source>
+        <translation>Změněno</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Typ</translation>
+    </message>
+    <message>
+        <source>File size</source>
+        <translation>Velikost souboru</translation>
+    </message>
+    <message>
+        <source>Duration</source>
+        <translation>Trvání</translation>
+    </message>
+    <message>
+        <source>Path</source>
+        <translation>Popis umístění</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation>Informace o videu</translation>
+    </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Datum pořízení</translation>
+    </message>
+</context>
 <context>
     <name>ViewPanel</name>
     <message>
