@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="fr">
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -58,14 +60,6 @@
         <source>Favorites</source>
         <translation>Favoris</translation>
     </message>
-    <message>
-        <source>Delete All</source>
-        <translation>Supprimer tout</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Supprimer</translation>
-    </message>
     <message>
         <source>Or drag photos here</source>
         <translation>Ou faites glisser des photos ici</translation>
@@ -80,36 +74,16 @@
     </message>
     <message>
         <source>The photos will be permanently deleted after the days shown on it</source>
-        <translation>Les photos seront supprimées définitivement après les jours indiqués dessus</translation>
-    </message>
-    <message>
-        <source>Restore</source>
-        <translation>Restaurer</translation>
-    </message>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>%1 photo(s) sélectionnée(s)</translation>
+        <translation type="vanished">Les photos seront supprimées définitivement après les jours indiqués dessus</translation>
     </message>
     <message>
         <source>Import to:</source>
         <translation>Importer vers  :</translation>
     </message>
-    <message>
-        <source>Disk</source>
-        <translation type="vanished">Disque</translation>
-    </message>
     <message>
         <source>Import</source>
         <translation>Importer</translation>
     </message>
-    <message>
-        <source>days</source>
-        <translation type="vanished">jours</translation>
-    </message>
-    <message>
-        <source>Unnamed</source>
-        <translation type="vanished">Sans nom</translation>
-    </message>
     <message>
         <source>System Disk</source>
         <translation>Disque système</translation>
@@ -140,18 +114,15 @@
     </message>
     <message>
         <source>Loading photos, please wait...</source>
-        <translation>Chargement des photos, veuillez patienter...</translation>
-    </message>
-</context>
-<context>
-    <name>AllPicView</name>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>%1 photo(s) sélectionnée(s)</translation>
+        <translation type="vanished">Chargement des photos, veuillez patienter...</translation>
     </message>
     <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 photo(s)</translation>
+        <source>Loading...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The files will be permanently deleted after the days shown on it</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -254,10 +225,6 @@
         <source>%1 Encrypted</source>
         <translation>%1 Chiffré</translation>
     </message>
-    <message>
-        <source>%1 </source>
-        <translation type="vanished">%1</translation>
-    </message>
     <message>
         <source>%1 Volume</source>
         <translation>%1 Volume</translation>
@@ -291,49 +258,16 @@
         <source>Deleting...</source>
         <translation>Suppression...</translation>
     </message>
-    <message>
-        <source>Importing...</source>
-        <translation>Importation...</translation>
-    </message>
     <message>
         <source>Restoring...</source>
         <translation>Restauration en cours...</translation>
     </message>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerie</translation>
-    </message>
-</context>
-<context>
-    <name>ImageImportFilesFromMountThread</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerie</translation>
-    </message>
-</context>
-<context>
-    <name>ImageInfoWidget</name>
-    <message>
-        <source>Basic info</source>
-        <translation type="vanished">Infos de l&apos;image</translation>
-    </message>
-    <message>
-        <source>Details</source>
-        <translation type="vanished">Détails</translation>
-    </message>
 </context>
 <context>
     <name>ImageLoadFromLocalThread</name>
     <message>
         <source>days</source>
-        <translation>jours</translation>
-    </message>
-</context>
-<context>
-    <name>ImageLoader</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerie</translation>
+        <translation type="vanished">jours</translation>
     </message>
 </context>
 <context>
@@ -352,7 +286,32 @@
     </message>
     <message>
         <source>Are you sure you want to delete %1 photos from albums?</source>
-        <translation>Voulez-vous vraiment supprimer %1 photos des albums ?</translation>
+        <translation type="vanished">Voulez-vous vraiment supprimer %1 photos des albums ?</translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n photos from albums?</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this video from the album?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n videos from albums?</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n items from albums?</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -370,37 +329,55 @@
         <translation>Informations sur la photo</translation>
     </message>
 </context>
-<context>
-    <name>ImportImagesThread</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerie</translation>
-    </message>
-</context>
 <context>
     <name>ImportTimeLineView</name>
     <message>
         <source>Import</source>
         <translation>Importer</translation>
     </message>
+    <message>
+        <source>1 photo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>ImportView</name>
     <message>
-        <source>All Photos</source>
-        <translation>Toutes les photos</translation>
+        <source>Import Photos and Videos</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Import Photos</source>
-        <translation>Importer des photos</translation>
+        <source>Or drag them here</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Or drag photos here</source>
-        <translation>Ou faites glisser des photos ici</translation>
-    </message>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerie</translation>
+        <source>All photos and videos</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -421,10 +398,6 @@
         <source>Delete</source>
         <translation>Supprimer</translation>
     </message>
-    <message>
-        <source>Unnamed</source>
-        <translation type="vanished">Sans nom</translation>
-    </message>
     <message>
         <source>Device</source>
         <translation>Appareil</translation>
@@ -446,14 +419,18 @@
     <name>LockWidget</name>
     <message>
         <source>You have no permission to view the image</source>
-        <translation>Vous n&apos;êtes pas autorisé à afficher l&apos;image</translation>
+        <translation type="vanished">Vous n&apos;êtes pas autorisé à afficher l&apos;image</translation>
+    </message>
+    <message>
+        <source>You have no permission to view the file</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>Main</name>
     <message>
-        <source>Album is a fashion photo manager for viewing and organizing pictures.</source>
-        <translation>Album est un gestionnaire de photos pour visualiser et organiser les photos.</translation>
+        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -550,13 +527,9 @@
         <source>Albums</source>
         <translation>Albums</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation type="vanished">%1 photo(s)</translation>
-    </message>
     <message>
         <source>Photo info</source>
-        <translation>Informations sur la photo</translation>
+        <translation type="vanished">Informations sur la photo</translation>
     </message>
     <message>
         <source>Exit fullscreen/slideshow</source>
@@ -572,11 +545,11 @@
     </message>
     <message>
         <source>Export</source>
-        <translation>Exporter</translation>
+        <translation type="vanished">Exporter</translation>
     </message>
     <message>
         <source>Import</source>
-        <translation>Importer</translation>
+        <translation type="vanished">Importer</translation>
     </message>
     <message>
         <source>Select all</source>
@@ -584,7 +557,7 @@
     </message>
     <message>
         <source>Delete photo/album</source>
-        <translation>Supprimer une photo / un album</translation>
+        <translation type="vanished">Supprimer une photo / un album</translation>
     </message>
     <message>
         <source>Zoom in</source>
@@ -610,37 +583,45 @@
         <source>Settings</source>
         <translation>Paramètres</translation>
     </message>
-    <message>
-        <source>Some photos have not been imported</source>
-        <translation type="vanished">Certaines photos n&apos;ont pas été importées</translation>
-    </message>
     <message>
         <source>Import photos</source>
         <translation>Importer des photos</translation>
     </message>
     <message>
         <source>Import Photos</source>
-        <translation>Importer des photos</translation>
-    </message>
-    <message>
-        <source>%1/%2 photos imported</source>
-        <translation>%1/%2 photos importées</translation>
-    </message>
-    <message>
-        <source>%1 photos imported, %2 photos failed</source>
-        <translation>%1 photos importées, %2 photos ont échoué</translation>
-    </message>
-    <message>
-        <source>%1/%2 photos deleted</source>
-        <translation>%1/%2 photos supprimées</translation>
+        <translation type="vanished">Importer des photos</translation>
     </message>
     <message>
         <source>Importing...</source>
         <translation>Importation...</translation>
     </message>
     <message>
-        <source>Photos already exist</source>
-        <translation>Les photos existent déjà</translation>
+        <source>All photos and videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import Photos and Videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Export photos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import photos/videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished">Supprimer</translation>
+    </message>
+    <message>
+        <source>Photo/Video info</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -731,78 +712,10 @@
     </message>
 </context>
 <context>
-    <name>MountThumbnailListView</name>
+    <name>NoResultWidget</name>
     <message>
-        <source>Photo info</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>View</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Restore</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Add to album</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation type="unfinished"/>
+        <source>No results</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -812,56 +725,6 @@
         <translation>Disque système</translation>
     </message>
 </context>
-<context>
-    <name>PrintOptionsPage</name>
-    <message>
-        <source>No scaling</source>
-        <translation type="vanished">Pas de mise à l&apos;échelle</translation>
-    </message>
-    <message>
-        <source>Fit page to image</source>
-        <translation type="vanished">Ajuster la page à l&apos;image</translation>
-    </message>
-    <message>
-        <source>Fit image to page</source>
-        <translation type="vanished">Ajuster l&apos;image à la page</translation>
-    </message>
-    <message>
-        <source>Scale to:</source>
-        <translation type="vanished">Échelle à :</translation>
-    </message>
-    <message>
-        <source>Millimeters</source>
-        <translation type="vanished">Millimètres</translation>
-    </message>
-    <message>
-        <source>Centimeters</source>
-        <translation type="vanished">Centimètres</translation>
-    </message>
-    <message>
-        <source>Inches</source>
-        <translation type="vanished">Pouces</translation>
-    </message>
-    <message>
-        <source>Image Position</source>
-        <translation type="vanished">Position de l&apos;image</translation>
-    </message>
-    <message>
-        <source>Scaling</source>
-        <translation type="vanished">Mise à l&apos;échelle</translation>
-    </message>
-    <message>
-        <source>Image Settings</source>
-        <translation type="vanished">Paramètres d&apos;image</translation>
-    </message>
-</context>
-<context>
-    <name>PrintPreviewDialog</name>
-    <message>
-        <source>Image Settings</source>
-        <translation type="vanished">Paramètres d&apos;image</translation>
-    </message>
-</context>
 <context>
     <name>QObject</name>
     <message>
@@ -878,19 +741,7 @@
     </message>
     <message>
         <source>%1 photo(s)</source>
-        <translation>%1 photo(s)</translation>
-    </message>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>%1 photo(s) sélectionnée(s)</translation>
-    </message>
-    <message>
-        <source>%1/%2/%3 %4</source>
-        <translation type="vanished">%1/%2/%3 %4</translation>
-    </message>
-    <message>
-        <source>Import on </source>
-        <translation type="vanished">Importer sur</translation>
+        <translation type="vanished">%1 photo(s)</translation>
     </message>
     <message>
         <source>Imported on</source>
@@ -904,6 +755,107 @@
         <source>Imported on </source>
         <translation>Importer vers </translation>
     </message>
+    <message>
+        <source>Select All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unselect All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation>Restaurer</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Supprimer</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Photos</source>
+        <translation>Photos</translation>
+    </message>
+    <message>
+        <source>Videos</source>
+        <translation>Vidéos</translation>
+    </message>
+    <message>
+        <source>No results</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation>Favoris</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation>Rotation dans le sens inverse</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation>Rotation dans le sens horaire</translation>
+    </message>
+    <message>
+        <source>Importing...</source>
+        <translation>Importation...</translation>
+    </message>
+    <message>
+        <source>%1/%2 items imported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1/%2 items deleted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 items imported, %2 items failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 photo selected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 video selected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The photo/video already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos selected</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos selected</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items selected</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>%1 items imported, %2 items exist already</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchView</name>
@@ -915,14 +867,39 @@
         <source>Slide Show</source>
         <translation>Diaporama</translation>
     </message>
-    <message>
-        <source>%1 photo(s) found</source>
-        <translation>%1 photo(s) trouvée(s)</translation>
-    </message>
     <message>
         <source>Search results</source>
         <translation>Résultats de la recherche</translation>
     </message>
+    <message>
+        <source>1 photo found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos found</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>1 video found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items found</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos found</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>SlideShowBottomBar</name>
@@ -951,11 +928,41 @@
     <name>StatusBar</name>
     <message>
         <source>Importing photos: &apos;%1&apos;</source>
-        <translation>Importation de photos : &apos;%1&apos;</translation>
+        <translation type="vanished">Importation de photos : &apos;%1&apos;</translation>
     </message>
     <message>
         <source>Exporting photos: &apos;%1&apos;</source>
-        <translation>Exportation de photos : &apos;%1&apos;</translation>
+        <translation type="vanished">Exportation de photos : &apos;%1&apos;</translation>
+    </message>
+    <message>
+        <source>1 photo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Importing: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exporting: %1</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1075,6 +1082,14 @@
         <source>Print</source>
         <translation>Imprimer</translation>
     </message>
+    <message>
+        <source>Video info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>days</source>
+        <translation type="unfinished">jours</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -1087,6 +1102,129 @@
         <translation>Photo introuvable</translation>
     </message>
 </context>
+<context>
+    <name>TimeLineView</name>
+    <message>
+        <source>1 photo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+</context>
+<context>
+    <name>VideoInfoDialog</name>
+    <message>
+        <source>Basic info</source>
+        <translation type="unfinished">Infos de l&apos;image</translation>
+    </message>
+    <message>
+        <source>Codec info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video CodecID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video CodeRate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FPS</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Proportion</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resolution</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio CodecID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio CodeRate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio digit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sampling</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date modified</source>
+        <translation type="unfinished">Date de modification</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished">Type</translation>
+    </message>
+    <message>
+        <source>File size</source>
+        <translation type="unfinished">Taille du fichier</translation>
+    </message>
+    <message>
+        <source>Duration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date captured</source>
+        <translation type="unfinished">Date de capture</translation>
+    </message>
+</context>
 <context>
     <name>ViewPanel</name>
     <message>
@@ -1166,4 +1304,4 @@
         <translation>Imprimer</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
