@@ -58,14 +58,6 @@
         <source>Favorites</source>
         <translation>Kedvencek</translation>
     </message>
-    <message>
-        <source>Delete All</source>
-        <translation>Összes törlése</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Törlés</translation>
-    </message>
     <message>
         <source>Or drag photos here</source>
         <translation>Vagy húzza a képeket ide</translation>
@@ -78,38 +70,14 @@
         <source>Import All</source>
         <translation>Összes importálása</translation>
     </message>
-    <message>
-        <source>The photos will be permanently deleted after the days shown on it</source>
-        <translation>A képek a feltüntetett nap után véglegesen törlődnek</translation>
-    </message>
-    <message>
-        <source>Restore</source>
-        <translation>Helyreállítás</translation>
-    </message>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>%1 kép(ek) kiválasztva</translation>
-    </message>
     <message>
         <source>Import to:</source>
         <translation>Importálás ide:</translation>
     </message>
-    <message>
-        <source>Disk</source>
-        <translation type="vanished">Lemez</translation>
-    </message>
     <message>
         <source>Import</source>
         <translation>Importálás</translation>
     </message>
-    <message>
-        <source>days</source>
-        <translation type="vanished">napok</translation>
-    </message>
-    <message>
-        <source>Unnamed</source>
-        <translation type="vanished">Névtelen</translation>
-    </message>
     <message>
         <source>System Disk</source>
         <translation>Rendszerlemez</translation>
@@ -139,19 +107,12 @@
         <translation>Kihagyás</translation>
     </message>
     <message>
-        <source>Loading photos, please wait...</source>
-        <translation>Fényképek betöltése, kérjük várjon...</translation>
-    </message>
-</context>
-<context>
-    <name>AllPicView</name>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>%1 kép(ek) kiválasztva</translation>
+        <source>Loading...</source>
+        <translation>Betöltés...</translation>
     </message>
     <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 kép(ek)</translation>
+        <source>The files will be permanently deleted after the days shown on it</source>
+        <translation>A fájlok véglegesen törlődnek a megjelenített napok után</translation>
     </message>
 </context>
 <context>
@@ -254,10 +215,6 @@
         <source>%1 Encrypted</source>
         <translation>%1 titkosítva</translation>
     </message>
-    <message>
-        <source>%1 </source>
-        <translation type="vanished">%1</translation>
-    </message>
     <message>
         <source>%1 Volume</source>
         <translation>%1 hangerő</translation>
@@ -291,50 +248,10 @@
         <source>Deleting...</source>
         <translation>Törlés...</translation>
     </message>
-    <message>
-        <source>Importing...</source>
-        <translation>Importálás...</translation>
-    </message>
     <message>
         <source>Restoring...</source>
         <translation>Visszaállítás...</translation>
     </message>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galéria</translation>
-    </message>
-</context>
-<context>
-    <name>ImageImportFilesFromMountThread</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galéria</translation>
-    </message>
-</context>
-<context>
-    <name>ImageInfoWidget</name>
-    <message>
-        <source>Basic info</source>
-        <translation type="vanished">Alapvető információk</translation>
-    </message>
-    <message>
-        <source>Details</source>
-        <translation type="vanished">Részletek</translation>
-    </message>
-</context>
-<context>
-    <name>ImageLoadFromLocalThread</name>
-    <message>
-        <source>days</source>
-        <translation>napok</translation>
-    </message>
-</context>
-<context>
-    <name>ImageLoader</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galéria</translation>
-    </message>
 </context>
 <context>
     <name>ImgDeleteDialog</name>
@@ -350,9 +267,21 @@
         <source>Are you sure you want to delete this photo from the album?</source>
         <translation>Biztos, hogy törölni szeretné ezt a képet az albumból?</translation>
     </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n photos from albums?</source>
+        <translation><numerusform>Biztos, hogy törölni szeretne %n képet az albumból?</numerusform><numerusform>Biztos, hogy törölni szeretne %n képet az albumból?</numerusform></translation>
+    </message>
     <message>
-        <source>Are you sure you want to delete %1 photos from albums?</source>
-        <translation>Biztos, hogy törölni szeretné a %1 képeket az albumból?</translation>
+        <source>Are you sure you want to delete this video from the album?</source>
+        <translation>Biztos, hogy törölni szeretné ezt a videót az albumból?</translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n videos from albums?</source>
+        <translation><numerusform>Biztos, hogy törölni szeretne %n videót az albumból?</numerusform><numerusform>Biztos, hogy törölni szeretne %n videót az albumból?</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n items from albums?</source>
+        <translation><numerusform>Biztos, hogy törölni szeretne %n elemet az albumból?</numerusform><numerusform>Biztos, hogy törölni szeretne %n elemet az albumból?</numerusform></translation>
     </message>
 </context>
 <context>
@@ -370,37 +299,46 @@
         <translation>Kép tulajdonságai</translation>
     </message>
 </context>
-<context>
-    <name>ImportImagesThread</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galéria</translation>
-    </message>
-</context>
 <context>
     <name>ImportTimeLineView</name>
     <message>
         <source>Import</source>
         <translation>Importálás</translation>
     </message>
+    <message>
+        <source>1 photo</source>
+        <translation>1 kép</translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation>1 videó</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n kép(ek)</numerusform><numerusform>%n kép(ek)</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n videó(k)</numerusform><numerusform>%n videó(k)</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items</source>
+        <translation><numerusform>%n elem(ek)</numerusform><numerusform>%n elem(ek)</numerusform></translation>
+    </message>
 </context>
 <context>
     <name>ImportView</name>
     <message>
-        <source>All Photos</source>
-        <translation>Összes kép</translation>
+        <source>Import Photos and Videos</source>
+        <translation>Képek és Videók importálása</translation>
     </message>
     <message>
-        <source>Import Photos</source>
-        <translation>Képek importálása</translation>
+        <source>Or drag them here</source>
+        <translation>Vagy húzza ide a fájlokat</translation>
     </message>
     <message>
-        <source>Or drag photos here</source>
-        <translation>Vagy húzza ide a képeket</translation>
-    </message>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galéria</translation>
+        <source>All photos and videos</source>
+        <translation>Összes Kép és Videó</translation>
     </message>
 </context>
 <context>
@@ -421,10 +359,6 @@
         <source>Delete</source>
         <translation>Törlés</translation>
     </message>
-    <message>
-        <source>Unnamed</source>
-        <translation type="vanished">Névtelen</translation>
-    </message>
     <message>
         <source>Device</source>
         <translation>Eszköz</translation>
@@ -445,14 +379,14 @@
 <context>
     <name>LockWidget</name>
     <message>
-        <source>You have no permission to view the image</source>
-        <translation>Nincs jogosultsága megtekinteni ezt a képet</translation>
+        <source>You have no permission to view the file</source>
+        <translation>Nincs jogosultsága a fájl megtekintésére</translation>
     </message>
 </context>
 <context>
     <name>Main</name>
     <message>
-        <source>Album is a fashion photo manager for viewing and organizing pictures.</source>
+        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
         <translation>Az Album egy divatos képkezelő képek nézegetésére és rendszerezésére</translation>
     </message>
 </context>
@@ -550,14 +484,6 @@
         <source>Albums</source>
         <translation>Albumok</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation type="vanished">%1 kép(ek)</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Kép tulajdonságai</translation>
-    </message>
     <message>
         <source>Exit fullscreen/slideshow</source>
         <translation>Kilépés a teljes képernyős módból vagy a diavetítésből</translation>
@@ -570,22 +496,10 @@
         <source>View</source>
         <translation>Nézet</translation>
     </message>
-    <message>
-        <source>Export</source>
-        <translation>Exportálás</translation>
-    </message>
-    <message>
-        <source>Import</source>
-        <translation>Importálás</translation>
-    </message>
     <message>
         <source>Select all</source>
         <translation>Összes kijelölése</translation>
     </message>
-    <message>
-        <source>Delete photo/album</source>
-        <translation>Kép vagy album törlése</translation>
-    </message>
     <message>
         <source>Zoom in</source>
         <translation>Nagyítás</translation>
@@ -610,37 +524,41 @@
         <source>Settings</source>
         <translation>Beállítások</translation>
     </message>
-    <message>
-        <source>Some photos have not been imported</source>
-        <translation type="vanished">Néhány kép nem került importálásra</translation>
-    </message>
     <message>
         <source>Import photos</source>
         <translation>Képek importálása</translation>
     </message>
-    <message>
-        <source>Import Photos</source>
-        <translation>Képek importálása</translation>
-    </message>
-    <message>
-        <source>%1/%2 photos imported</source>
-        <translation>%1/%2 kép importálva</translation>
-    </message>
-    <message>
-        <source>%1 photos imported, %2 photos failed</source>
-        <translation>%1 kép importálva, %2 kép importálása sikertelen</translation>
-    </message>
-    <message>
-        <source>%1/%2 photos deleted</source>
-        <translation>%1/%2 kép törölve</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Importálás...</translation>
     </message>
     <message>
-        <source>Photos already exist</source>
-        <translation>A kép már létezik</translation>
+        <source>All photos and videos</source>
+        <translation>Összes Kép és Videó</translation>
+    </message>
+    <message>
+        <source>Import Photos and Videos</source>
+        <translation>Képek és Videók importálása</translation>
+    </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Nem található kép vagy videó</translation>
+    </message>
+    <message>
+        <source>Export photos</source>
+        <translation>Képek exportálása</translation>
+    </message>
+    <message>
+        <source>Import photos/videos</source>
+        <translation>Képek/Videók importálása</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Törlés</translation>
+    </message>
+    <message>
+        <source>Photo/Video info</source>
+        <translation>Kép/Videó tulajdonságai</translation>
     </message>
 </context>
 <context>
@@ -731,78 +649,10 @@
     </message>
 </context>
 <context>
-    <name>MountThumbnailListView</name>
+    <name>NoResultWidget</name>
     <message>
-        <source>Photo info</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>View</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Restore</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Add to album</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation type="unfinished"/>
+        <source>No results</source>
+        <translation>Nincs keresési eredmény</translation>
     </message>
 </context>
 <context>
@@ -812,56 +662,6 @@
         <translation>Rendszerlemez</translation>
     </message>
 </context>
-<context>
-    <name>PrintOptionsPage</name>
-    <message>
-        <source>No scaling</source>
-        <translation type="vanished">Nincs méretezés</translation>
-    </message>
-    <message>
-        <source>Fit page to image</source>
-        <translation type="vanished">Oldal illesztése a képhez</translation>
-    </message>
-    <message>
-        <source>Fit image to page</source>
-        <translation type="vanished">Kép illesztése az oldalhoz</translation>
-    </message>
-    <message>
-        <source>Scale to:</source>
-        <translation type="vanished">Méretezés:</translation>
-    </message>
-    <message>
-        <source>Millimeters</source>
-        <translation type="vanished">Miliméter</translation>
-    </message>
-    <message>
-        <source>Centimeters</source>
-        <translation type="vanished">Centiméter</translation>
-    </message>
-    <message>
-        <source>Inches</source>
-        <translation type="vanished">Hüvelyk</translation>
-    </message>
-    <message>
-        <source>Image Position</source>
-        <translation type="vanished">Kép elhelyezkedése</translation>
-    </message>
-    <message>
-        <source>Scaling</source>
-        <translation type="vanished">Méretezés</translation>
-    </message>
-    <message>
-        <source>Image Settings</source>
-        <translation type="vanished">Kép beállításai</translation>
-    </message>
-</context>
-<context>
-    <name>PrintPreviewDialog</name>
-    <message>
-        <source>Image Settings</source>
-        <translation type="vanished">Kép beállításai</translation>
-    </message>
-</context>
 <context>
     <name>QObject</name>
     <message>
@@ -876,22 +676,6 @@
         <source>%1/%2/%3</source>
         <translation>%1/%2/%3</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 kép(ek)</translation>
-    </message>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>%1 kép(ek) kijelölve</translation>
-    </message>
-    <message>
-        <source>%1/%2/%3 %4</source>
-        <translation type="vanished">%1/%2/%3 %4</translation>
-    </message>
-    <message>
-        <source>Import on </source>
-        <translation type="vanished">Importálás ide</translation>
-    </message>
     <message>
         <source>Imported on</source>
         <translation>Importálva ide</translation>
@@ -904,6 +688,98 @@
         <source>Imported on </source>
         <translation>Importálva ide</translation>
     </message>
+    <message>
+        <source>Select All</source>
+        <translation>Összes kijelölése</translation>
+    </message>
+    <message>
+        <source>Unselect All</source>
+        <translation>Összes kijelölésének megszüntetése</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Mégsem</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation>Helyreállítás</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Törlés</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Összes</translation>
+    </message>
+    <message>
+        <source>Photos</source>
+        <translation>Képek</translation>
+    </message>
+    <message>
+        <source>Videos</source>
+        <translation>Videók</translation>
+    </message>
+    <message>
+        <source>No results</source>
+        <translation>Nincs keresési eredmény</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation>Kedvenc</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation>Forgatás az óramutató járásával megegyezően</translation>
+    </message>
+    <message>
+        <source>Importing...</source>
+        <translation>Importálás...</translation>
+    </message>
+    <message>
+        <source>%1/%2 items imported</source>
+        <translation>%1/%2 elem importálva</translation>
+    </message>
+    <message>
+        <source>%1/%2 items deleted</source>
+        <translation>%1/%2 elem törölve</translation>
+    </message>
+    <message>
+        <source>%1 items imported, %2 items failed</source>
+        <translation>%1 elem importálva, %2 elem importálása sikertelen</translation>
+    </message>
+    <message>
+        <source>1 photo selected</source>
+        <translation>1 kép kijelölve</translation>
+    </message>
+    <message>
+        <source>1 video selected</source>
+        <translation>1 videó kijelölve</translation>
+    </message>
+    <message>
+        <source>The photo/video already exists</source>
+        <translation>A kép/videó már létezik</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos selected</source>
+        <translation><numerusform>%n kép(ek) kijelölve</numerusform><numerusform>%n kép(ek) kijelölve</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos selected</source>
+        <translation><numerusform>%n videó kijelölve</numerusform><numerusform>%n videó kijelölve</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items selected</source>
+        <translation><numerusform>%n elem(ek) kijelölve</numerusform><numerusform>%n elem(ek) kijelölve</numerusform></translation>
+    </message>
+    <message>
+        <source>%1 items imported, %2 items exist already</source>
+        <translation>%1 elem importálva, %2 elem már létezik</translation>
+    </message>
 </context>
 <context>
     <name>SearchView</name>
@@ -915,14 +791,30 @@
         <source>Slide Show</source>
         <translation>Diavetítés</translation>
     </message>
-    <message>
-        <source>%1 photo(s) found</source>
-        <translation>%1 képe(ke)t sikerült találni</translation>
-    </message>
     <message>
         <source>Search results</source>
         <translation>Keresési eredmények</translation>
     </message>
+    <message>
+        <source>1 photo found</source>
+        <translation>1 képet sikerült találni</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos found</source>
+        <translation><numerusform>%n videót sikerült találni</numerusform><numerusform>%n videót sikerült találni</numerusform></translation>
+    </message>
+    <message>
+        <source>1 video found</source>
+        <translation>1 videót sikerült találni</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items found</source>
+        <translation><numerusform>%n elemet sikerült találni</numerusform><numerusform>%n elemet sikerült találni</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos found</source>
+        <translation><numerusform>%n képe(ke)t sikerült találni</numerusform><numerusform>%n képe(ke)t sikerült találni</numerusform></translation>
+    </message>
 </context>
 <context>
     <name>SlideShowBottomBar</name>
@@ -950,12 +842,28 @@
 <context>
     <name>StatusBar</name>
     <message>
-        <source>Importing photos: &apos;%1&apos;</source>
-        <translation>Importálandó képek: &apos;%1&apos;</translation>
+        <source>1 photo</source>
+        <translation>1 kép</translation>
     </message>
     <message>
-        <source>Exporting photos: &apos;%1&apos;</source>
-        <translation>Exportálandó képek: &apos;%1&apos;</translation>
+        <source>1 video</source>
+        <translation>1 videó</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n kép(ek)</numerusform><numerusform>%n kép(ek)</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n videó(k)</numerusform><numerusform>%n videó(k)</numerusform></translation>
+    </message>
+    <message>
+        <source>Importing: %1</source>
+        <translation>Importálás: %1</translation>
+    </message>
+    <message>
+        <source>Exporting: %1</source>
+        <translation>Exportálás: %1</translation>
     </message>
 </context>
 <context>
@@ -1075,6 +983,14 @@
         <source>Print</source>
         <translation>Nyomtatás</translation>
     </message>
+    <message>
+        <source>Video info</source>
+        <translation>Videó tulajdonságai</translation>
+    </message>
+    <message>
+        <source>days</source>
+        <translation>napok</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -1087,6 +1003,120 @@
         <translation>Kép nem található</translation>
     </message>
 </context>
+<context>
+    <name>TimeLineView</name>
+    <message>
+        <source>1 photo</source>
+        <translation>1 kép</translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation>1 videó</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n kép(ek)</numerusform><numerusform>%n kép(ek)</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n videó(k)</numerusform><numerusform>%n videó(k)</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items</source>
+        <translation><numerusform>%n elem(ek)</numerusform><numerusform>%n elem(ek)</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>VideoInfoDialog</name>
+    <message>
+        <source>Basic info</source>
+        <translation>Alapvető információk</translation>
+    </message>
+    <message>
+        <source>Codec info</source>
+        <translation>Kodek tulajdonságai</translation>
+    </message>
+    <message>
+        <source>Audio info</source>
+        <translation>Audió tulajdonságai</translation>
+    </message>
+    <message>
+        <source>Video CodecID</source>
+        <translation>Videó kodek azonosító</translation>
+    </message>
+    <message>
+        <source>Video CodeRate</source>
+        <translation>Videó kodek érték</translation>
+    </message>
+    <message>
+        <source>FPS</source>
+        <translation>FPS</translation>
+    </message>
+    <message>
+        <source>Proportion</source>
+        <translation>Arány</translation>
+    </message>
+    <message>
+        <source>Resolution</source>
+        <translation>Felbontás</translation>
+    </message>
+    <message>
+        <source>Audio CodecID</source>
+        <translation>Audió kodek azonosító</translation>
+    </message>
+    <message>
+        <source>Audio CodeRate</source>
+        <translation>Audió kodek érték</translation>
+    </message>
+    <message>
+        <source>Audio digit</source>
+        <translation>Audió számjegy</translation>
+    </message>
+    <message>
+        <source>Channels</source>
+        <translation>Csatornák</translation>
+    </message>
+    <message>
+        <source>Channel</source>
+        <translation>Csatorna</translation>
+    </message>
+    <message>
+        <source>Sampling</source>
+        <translation>Mintavétel</translation>
+    </message>
+    <message>
+        <source>Video name</source>
+        <translation>Videó neve</translation>
+    </message>
+    <message>
+        <source>Date modified</source>
+        <translation>Módosítás ideje</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Tipus</translation>
+    </message>
+    <message>
+        <source>File size</source>
+        <translation>Fájlméret</translation>
+    </message>
+    <message>
+        <source>Duration</source>
+        <translation>Időtartam</translation>
+    </message>
+    <message>
+        <source>Path</source>
+        <translation>Elérési útvonal</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation>Videó tulajdonságai</translation>
+    </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Rögzítés dátuma</translation>
+    </message>
+</context>
 <context>
     <name>ViewPanel</name>
     <message>
