@@ -58,14 +58,6 @@
         <source>Favorites</source>
         <translation>Favorieten</translation>
     </message>
-    <message>
-        <source>Delete All</source>
-        <translation>Alles verwijderen</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Verwijderen</translation>
-    </message>
     <message>
         <source>Or drag photos here</source>
         <translation>of sleep foto&apos;s hierheen</translation>
@@ -78,38 +70,14 @@
         <source>Import All</source>
         <translation>Alles importeren</translation>
     </message>
-    <message>
-        <source>The photos will be permanently deleted after the days shown on it</source>
-        <translation>De foto&apos;s worden verwijderd na het vermelde aantal dagen</translation>
-    </message>
-    <message>
-        <source>Restore</source>
-        <translation>Herstellen</translation>
-    </message>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>%1 foto(&apos;s) geselecteerd</translation>
-    </message>
     <message>
         <source>Import to:</source>
         <translation>Importeren naar:</translation>
     </message>
-    <message>
-        <source>Disk</source>
-        <translation type="vanished">Schijf</translation>
-    </message>
     <message>
         <source>Import</source>
         <translation>Importeren</translation>
     </message>
-    <message>
-        <source>days</source>
-        <translation type="vanished">dagen</translation>
-    </message>
-    <message>
-        <source>Unnamed</source>
-        <translation type="vanished">Naamloos</translation>
-    </message>
     <message>
         <source>System Disk</source>
         <translation>Systeemschijf</translation>
@@ -139,19 +107,12 @@
         <translation>Negeren</translation>
     </message>
     <message>
-        <source>Loading photos, please wait...</source>
-        <translation>Bezig met laden van foto&apos;s...</translation>
-    </message>
-</context>
-<context>
-    <name>AllPicView</name>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>%1 foto(&apos;s) geselecteerd</translation>
+        <source>Loading...</source>
+        <translation>Bezig met laden…</translation>
     </message>
     <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 foto(&apos;s)</translation>
+        <source>The files will be permanently deleted after the days shown on it</source>
+        <translation>De bestanden worden verwijderd na het vermelde aantal dagen</translation>
     </message>
 </context>
 <context>
@@ -254,10 +215,6 @@
         <source>%1 Encrypted</source>
         <translation>%1-versleuteld</translation>
     </message>
-    <message>
-        <source>%1 </source>
-        <translation type="vanished">%1 </translation>
-    </message>
     <message>
         <source>%1 Volume</source>
         <translation>%1-schijf</translation>
@@ -289,51 +246,11 @@
     <name>ImageEngineApi</name>
     <message>
         <source>Deleting...</source>
-        <translation>Bezig met verwijderen...</translation>
-    </message>
-    <message>
-        <source>Importing...</source>
-        <translation>Bezig met importeren...</translation>
+        <translation>Bezig met verwijderen…</translation>
     </message>
     <message>
         <source>Restoring...</source>
-        <translation>Bezig met herstellen...</translation>
-    </message>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerij</translation>
-    </message>
-</context>
-<context>
-    <name>ImageImportFilesFromMountThread</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerij</translation>
-    </message>
-</context>
-<context>
-    <name>ImageInfoWidget</name>
-    <message>
-        <source>Basic info</source>
-        <translation type="vanished">Eigenschappen</translation>
-    </message>
-    <message>
-        <source>Details</source>
-        <translation type="vanished">Details</translation>
-    </message>
-</context>
-<context>
-    <name>ImageLoadFromLocalThread</name>
-    <message>
-        <source>days</source>
-        <translation>dagen</translation>
-    </message>
-</context>
-<context>
-    <name>ImageLoader</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerij</translation>
+        <translation>Bezig met herstellen…</translation>
     </message>
 </context>
 <context>
@@ -350,9 +267,21 @@
         <source>Are you sure you want to delete this photo from the album?</source>
         <translation>Weet je zeker dat je deze foto wilt verwijderen uit het album?</translation>
     </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n photos from albums?</source>
+        <translation><numerusform>Weet je zeker dat je %1 foto wilt verwijderen uit albums?</numerusform><numerusform>Weet je zeker dat je %n foto&apos;s wilt verwijderen uit albums?</numerusform></translation>
+    </message>
     <message>
-        <source>Are you sure you want to delete %1 photos from albums?</source>
-        <translation>Weet je zeker dat je %1 foto&apos;s wilt verwijderen uit het album?</translation>
+        <source>Are you sure you want to delete this video from the album?</source>
+        <translation>Weet je zeker dat je deze video wilt verwijderen uit het album?</translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n videos from albums?</source>
+        <translation><numerusform>Weet je zeker dat je %n video wilt verwijderen uit albums?</numerusform><numerusform>Weet je zeker dat je %n video&apos;s wilt verwijderen uit albums?</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n items from albums?</source>
+        <translation><numerusform>Weet je zeker dat je %n item wilt verwijderen uit albums?</numerusform><numerusform>Weet je zeker dat je %n items wilt verwijderen uit albums?</numerusform></translation>
     </message>
 </context>
 <context>
@@ -370,37 +299,46 @@
         <translation>Foto-informatie</translation>
     </message>
 </context>
-<context>
-    <name>ImportImagesThread</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerij</translation>
-    </message>
-</context>
 <context>
     <name>ImportTimeLineView</name>
     <message>
         <source>Import</source>
         <translation>Importeren</translation>
     </message>
+    <message>
+        <source>1 photo</source>
+        <translation>1 foto</translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation>1 video</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n foto</numerusform><numerusform>%n foto&apos;s</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n video</numerusform><numerusform>%n video&apos;s</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items</source>
+        <translation><numerusform>%n item</numerusform><numerusform>%n items</numerusform></translation>
+    </message>
 </context>
 <context>
     <name>ImportView</name>
     <message>
-        <source>All Photos</source>
-        <translation>Alle foto&apos;s</translation>
+        <source>Import Photos and Videos</source>
+        <translation>Importeer foto&apos;s en video&apos;s</translation>
     </message>
     <message>
-        <source>Import Photos</source>
-        <translation>Importeer foto&apos;s</translation>
+        <source>Or drag them here</source>
+        <translation>of sleep ze hierheen</translation>
     </message>
     <message>
-        <source>Or drag photos here</source>
-        <translation>of sleep foto&apos;s hierheen</translation>
-    </message>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Galerij</translation>
+        <source>All photos and videos</source>
+        <translation>Alle foto&apos;s en video&apos;s</translation>
     </message>
 </context>
 <context>
@@ -421,10 +359,6 @@
         <source>Delete</source>
         <translation>Verwijderen</translation>
     </message>
-    <message>
-        <source>Unnamed</source>
-        <translation type="vanished">Naamloos</translation>
-    </message>
     <message>
         <source>Device</source>
         <translation>Apparaat</translation>
@@ -445,15 +379,15 @@
 <context>
     <name>LockWidget</name>
     <message>
-        <source>You have no permission to view the image</source>
-        <translation>Je bent niet gemachtigd om deze foto te bekijken</translation>
+        <source>You have no permission to view the file</source>
+        <translation>Je bent niet bevoegd om dit bestand te bekijken</translation>
     </message>
 </context>
 <context>
     <name>Main</name>
     <message>
-        <source>Album is a fashion photo manager for viewing and organizing pictures.</source>
-        <translation>Album is een mooi vormgegeven progrmma waarmee je afbeeldingen kunt bekijken en beheren.</translation>
+        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
+        <translation>Album is een mooi vormgegeven programma waarmee je foto&apos;s en video&apos;s kunt bekijken en beheren.</translation>
     </message>
 </context>
 <context>
@@ -550,14 +484,6 @@
         <source>Albums</source>
         <translation>Albums</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation type="vanished">%1 foto(&apos;s)</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Foto-informatie</translation>
-    </message>
     <message>
         <source>Exit fullscreen/slideshow</source>
         <translation>Beeldvullende modus verlaten</translation>
@@ -570,22 +496,10 @@
         <source>View</source>
         <translation>Bekijken</translation>
     </message>
-    <message>
-        <source>Export</source>
-        <translation>Exporteren</translation>
-    </message>
-    <message>
-        <source>Import</source>
-        <translation>Importeren</translation>
-    </message>
     <message>
         <source>Select all</source>
         <translation>Alles selecteren</translation>
     </message>
-    <message>
-        <source>Delete photo/album</source>
-        <translation>Foto/Album verwijderen</translation>
-    </message>
     <message>
         <source>Zoom in</source>
         <translation>Inzoomen</translation>
@@ -610,37 +524,41 @@
         <source>Settings</source>
         <translation>Instellingen</translation>
     </message>
-    <message>
-        <source>Some photos have not been imported</source>
-        <translation type="vanished">Enkele foto&apos;s zijn niet geïmporteerd</translation>
-    </message>
     <message>
         <source>Import photos</source>
         <translation>Foto&apos;s importeren</translation>
     </message>
-    <message>
-        <source>Import Photos</source>
-        <translation>Foto&apos;s importeren</translation>
-    </message>
-    <message>
-        <source>%1/%2 photos imported</source>
-        <translation>%1/%2 foto&apos;s geïmporteerd</translation>
-    </message>
-    <message>
-        <source>%1 photos imported, %2 photos failed</source>
-        <translation>%1 foto&apos;s geïmporteerd - %2 mislukt</translation>
-    </message>
-    <message>
-        <source>%1/%2 photos deleted</source>
-        <translation>%1/%2 foto&apos;s verwijderd</translation>
-    </message>
     <message>
         <source>Importing...</source>
-        <translation>Bezig met importeren...</translation>
+        <translation>Bezig met importeren…</translation>
     </message>
     <message>
-        <source>Photos already exist</source>
-        <translation>De foto&apos;s zijn al aanwezig</translation>
+        <source>All photos and videos</source>
+        <translation>Alle foto&apos;s en video&apos;s</translation>
+    </message>
+    <message>
+        <source>Import Photos and Videos</source>
+        <translation>Importeer foto&apos;s en video&apos;s</translation>
+    </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Geen foto&apos;s of video&apos;s aangetroffen</translation>
+    </message>
+    <message>
+        <source>Export photos</source>
+        <translation>Foto&apos;s exporteren</translation>
+    </message>
+    <message>
+        <source>Import photos/videos</source>
+        <translation>Foto&apos;s/Video&apos;s importeren</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Verwijderen</translation>
+    </message>
+    <message>
+        <source>Photo/Video info</source>
+        <translation>Foto-/Video-informatie</translation>
     </message>
 </context>
 <context>
@@ -731,78 +649,10 @@
     </message>
 </context>
 <context>
-    <name>MountThumbnailListView</name>
+    <name>NoResultWidget</name>
     <message>
-        <source>Photo info</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>View</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Restore</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Add to album</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation type="unfinished"/>
+        <source>No results</source>
+        <translation>Geen zoekresultaten</translation>
     </message>
 </context>
 <context>
@@ -812,56 +662,6 @@
         <translation>Systeemschijf</translation>
     </message>
 </context>
-<context>
-    <name>PrintOptionsPage</name>
-    <message>
-        <source>No scaling</source>
-        <translation type="vanished">Niet inpassen</translation>
-    </message>
-    <message>
-        <source>Fit page to image</source>
-        <translation type="vanished">Pagina aanpassen aan afbeelding</translation>
-    </message>
-    <message>
-        <source>Fit image to page</source>
-        <translation type="vanished">Afbeelding aanpassen aan pagina</translation>
-    </message>
-    <message>
-        <source>Scale to:</source>
-        <translation type="vanished">Aanpassen aan:</translation>
-    </message>
-    <message>
-        <source>Millimeters</source>
-        <translation type="vanished">Millimeter</translation>
-    </message>
-    <message>
-        <source>Centimeters</source>
-        <translation type="vanished">Centimeter</translation>
-    </message>
-    <message>
-        <source>Inches</source>
-        <translation type="vanished">Inch</translation>
-    </message>
-    <message>
-        <source>Image Position</source>
-        <translation type="vanished">Afbeeldingspositie</translation>
-    </message>
-    <message>
-        <source>Scaling</source>
-        <translation type="vanished">Inpassen</translation>
-    </message>
-    <message>
-        <source>Image Settings</source>
-        <translation type="vanished">Afbeeldingsinstellingen</translation>
-    </message>
-</context>
-<context>
-    <name>PrintPreviewDialog</name>
-    <message>
-        <source>Image Settings</source>
-        <translation type="vanished">Afbeeldingsinstellingen</translation>
-    </message>
-</context>
 <context>
     <name>QObject</name>
     <message>
@@ -876,22 +676,6 @@
         <source>%1/%2/%3</source>
         <translation>%1/%2/%3</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 foto(&apos;s)</translation>
-    </message>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>%1 foto(&apos;s) geselecteerd</translation>
-    </message>
-    <message>
-        <source>%1/%2/%3 %4</source>
-        <translation type="vanished">%1/%2/%3 %4</translation>
-    </message>
-    <message>
-        <source>Import on </source>
-        <translation type="vanished">Importeren naar </translation>
-    </message>
     <message>
         <source>Imported on</source>
         <translation>Geïmporteerd op</translation>
@@ -904,6 +688,98 @@
         <source>Imported on </source>
         <translation>Geïmporteerd op</translation>
     </message>
+    <message>
+        <source>Select All</source>
+        <translation>Alles selecteren</translation>
+    </message>
+    <message>
+        <source>Unselect All</source>
+        <translation>Niets selecteren</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annuleren</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation>Herstellen</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Verwijderen</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Alles</translation>
+    </message>
+    <message>
+        <source>Photos</source>
+        <translation>Foto&apos;s</translation>
+    </message>
+    <message>
+        <source>Videos</source>
+        <translation>Video&apos;s</translation>
+    </message>
+    <message>
+        <source>No results</source>
+        <translation>Geen zoekresultaten</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation>Toev. aan favorieten</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation>Naar links draaien</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation>Naar rechts draaien</translation>
+    </message>
+    <message>
+        <source>Importing...</source>
+        <translation>Bezig met importeren…</translation>
+    </message>
+    <message>
+        <source>%1/%2 items imported</source>
+        <translation>%1/%2 items geïmporteerd</translation>
+    </message>
+    <message>
+        <source>%1/%2 items deleted</source>
+        <translation>%1/%2 items verwijderd</translation>
+    </message>
+    <message>
+        <source>%1 items imported, %2 items failed</source>
+        <translation>%1 items geïmporteerd - %2 mislukt</translation>
+    </message>
+    <message>
+        <source>1 photo selected</source>
+        <translation>1 foto geselecteerd</translation>
+    </message>
+    <message>
+        <source>1 video selected</source>
+        <translation>1 video geselecteerd</translation>
+    </message>
+    <message>
+        <source>The photo/video already exists</source>
+        <translation>De foto/video is al aanwezig</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos selected</source>
+        <translation><numerusform>%n foto geselecteerd</numerusform><numerusform>%n foto&apos;s geselecteerd</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos selected</source>
+        <translation><numerusform>%n video geselecteerd</numerusform><numerusform>%n video&apos;s geselecteerd</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items selected</source>
+        <translation><numerusform>%n item geselecteerd</numerusform><numerusform>%n items geselecteerd</numerusform></translation>
+    </message>
+    <message>
+        <source>%1 items imported, %2 items exist already</source>
+        <translation>%1 items geïmporteerd - %2 items reeds aanwezig</translation>
+    </message>
 </context>
 <context>
     <name>SearchView</name>
@@ -915,14 +791,30 @@
         <source>Slide Show</source>
         <translation>Diavoorstelling</translation>
     </message>
-    <message>
-        <source>%1 photo(s) found</source>
-        <translation>%1 foto(&apos;s) gevonden</translation>
-    </message>
     <message>
         <source>Search results</source>
         <translation>Geen zoekresultaten</translation>
     </message>
+    <message>
+        <source>1 photo found</source>
+        <translation>1 foto gevonden</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos found</source>
+        <translation><numerusform>%n video gevonden</numerusform><numerusform>%n video&apos;s gevonden</numerusform></translation>
+    </message>
+    <message>
+        <source>1 video found</source>
+        <translation>1 video gevonden</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items found</source>
+        <translation><numerusform>%n item gevonden</numerusform><numerusform>%n items gevonden</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos found</source>
+        <translation><numerusform>%n foto gevonden</numerusform><numerusform>%n foto&apos;s gevonden</numerusform></translation>
+    </message>
 </context>
 <context>
     <name>SlideShowBottomBar</name>
@@ -950,12 +842,28 @@
 <context>
     <name>StatusBar</name>
     <message>
-        <source>Importing photos: &apos;%1&apos;</source>
-        <translation>Bezig met importeren: &apos;%1&apos;</translation>
+        <source>1 photo</source>
+        <translation>1 foto</translation>
     </message>
     <message>
-        <source>Exporting photos: &apos;%1&apos;</source>
-        <translation>Bezig met exporteren: &apos;%1&apos;</translation>
+        <source>1 video</source>
+        <translation>1 video</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n foto</numerusform><numerusform>%n foto&apos;s</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n video</numerusform><numerusform>%n video&apos;s</numerusform></translation>
+    </message>
+    <message>
+        <source>Importing: %1</source>
+        <translation>Bezig met importeren van %1</translation>
+    </message>
+    <message>
+        <source>Exporting: %1</source>
+        <translation>Bezig met exporteren van %1</translation>
     </message>
 </context>
 <context>
@@ -1075,6 +983,14 @@
         <source>Print</source>
         <translation>Afdrukken</translation>
     </message>
+    <message>
+        <source>Video info</source>
+        <translation>Video-informatie</translation>
+    </message>
+    <message>
+        <source>days</source>
+        <translation>dagen</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -1087,6 +1003,120 @@
         <translation>Foto niet aangetroffen</translation>
     </message>
 </context>
+<context>
+    <name>TimeLineView</name>
+    <message>
+        <source>1 photo</source>
+        <translation>1 foto</translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation>1 video</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n foto</numerusform><numerusform>%n foto&apos;s</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n video</numerusform><numerusform>%n video&apos;s</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items</source>
+        <translation><numerusform>%n item</numerusform><numerusform>%n items</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>VideoInfoDialog</name>
+    <message>
+        <source>Basic info</source>
+        <translation>Eigenschappen</translation>
+    </message>
+    <message>
+        <source>Codec info</source>
+        <translation>Codecinformatie</translation>
+    </message>
+    <message>
+        <source>Audio info</source>
+        <translation>Audio-informatie</translation>
+    </message>
+    <message>
+        <source>Video CodecID</source>
+        <translation>Videocodec-id</translation>
+    </message>
+    <message>
+        <source>Video CodeRate</source>
+        <translation>Videocoderingssnelheid</translation>
+    </message>
+    <message>
+        <source>FPS</source>
+        <translation>FPS</translation>
+    </message>
+    <message>
+        <source>Proportion</source>
+        <translation>Beeldverhouding</translation>
+    </message>
+    <message>
+        <source>Resolution</source>
+        <translation>Resolutie</translation>
+    </message>
+    <message>
+        <source>Audio CodecID</source>
+        <translation>Audiocodec-id</translation>
+    </message>
+    <message>
+        <source>Audio CodeRate</source>
+        <translation>Audiocoderingssnelheid</translation>
+    </message>
+    <message>
+        <source>Audio digit</source>
+        <translation>Audio digit</translation>
+    </message>
+    <message>
+        <source>Channels</source>
+        <translation>Kanalen</translation>
+    </message>
+    <message>
+        <source>Channel</source>
+        <translation>Kanaal</translation>
+    </message>
+    <message>
+        <source>Sampling</source>
+        <translation>Sampling</translation>
+    </message>
+    <message>
+        <source>Video name</source>
+        <translation>Videonaam</translation>
+    </message>
+    <message>
+        <source>Date modified</source>
+        <translation>Aangepast op</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Type</translation>
+    </message>
+    <message>
+        <source>File size</source>
+        <translation>Bestandsgrootte</translation>
+    </message>
+    <message>
+        <source>Duration</source>
+        <translation>Duur</translation>
+    </message>
+    <message>
+        <source>Path</source>
+        <translation>Locatie</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation>Video-informatie</translation>
+    </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Genomen op</translation>
+    </message>
+</context>
 <context>
     <name>ViewPanel</name>
     <message>
