@@ -58,14 +58,6 @@
         <source>Favorites</source>
         <translation>Избранные</translation>
     </message>
-    <message>
-        <source>Delete All</source>
-        <translation>Удалить всё</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Удалить</translation>
-    </message>
     <message>
         <source>Or drag photos here</source>
         <translation>Или перетащите фотографии сюда</translation>
@@ -78,38 +70,14 @@
         <source>Import All</source>
         <translation>Импортировать всё</translation>
     </message>
-    <message>
-        <source>The photos will be permanently deleted after the days shown on it</source>
-        <translation>Фотографии будут удалены безвозвратно по истечении указанного  срока.</translation>
-    </message>
-    <message>
-        <source>Restore</source>
-        <translation>Восстановить</translation>
-    </message>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>%1 фото(графий) выбрано</translation>
-    </message>
     <message>
         <source>Import to:</source>
         <translation>Импортировать в:</translation>
     </message>
-    <message>
-        <source>Disk</source>
-        <translation type="vanished">Диск</translation>
-    </message>
     <message>
         <source>Import</source>
         <translation>Импортировать</translation>
     </message>
-    <message>
-        <source>days</source>
-        <translation type="vanished">дней</translation>
-    </message>
-    <message>
-        <source>Unnamed</source>
-        <translation type="vanished">Безымянный</translation>
-    </message>
     <message>
         <source>System Disk</source>
         <translation>Системный диск</translation>
@@ -139,19 +107,12 @@
         <translation>Игнорировать</translation>
     </message>
     <message>
-        <source>Loading photos, please wait...</source>
-        <translation>Загрузка фотографий, пожалуйста, подождите...</translation>
-    </message>
-</context>
-<context>
-    <name>AllPicView</name>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>% 1 фото(графий) выбрано</translation>
+        <source>Loading...</source>
+        <translation>Загрузка...</translation>
     </message>
     <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 фото(графий)</translation>
+        <source>The files will be permanently deleted after the days shown on it</source>
+        <translation>Файлы будут безвозвратно удалены по истечении указанного времени</translation>
     </message>
 </context>
 <context>
@@ -254,10 +215,6 @@
         <source>%1 Encrypted</source>
         <translation>% 1 Зашифровано</translation>
     </message>
-    <message>
-        <source>%1 </source>
-        <translation type="vanished">%1</translation>
-    </message>
     <message>
         <source>%1 Volume</source>
         <translation>%1 Том</translation>
@@ -291,50 +248,10 @@
         <source>Deleting...</source>
         <translation>Удаление...</translation>
     </message>
-    <message>
-        <source>Importing...</source>
-        <translation>Импортирование...</translation>
-    </message>
     <message>
         <source>Restoring...</source>
         <translation>Восстановление...</translation>
     </message>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Галерея</translation>
-    </message>
-</context>
-<context>
-    <name>ImageImportFilesFromMountThread</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Галерея</translation>
-    </message>
-</context>
-<context>
-    <name>ImageInfoWidget</name>
-    <message>
-        <source>Basic info</source>
-        <translation type="vanished">Основная информация</translation>
-    </message>
-    <message>
-        <source>Details</source>
-        <translation type="vanished">Подробные сведения</translation>
-    </message>
-</context>
-<context>
-    <name>ImageLoadFromLocalThread</name>
-    <message>
-        <source>days</source>
-        <translation>дней</translation>
-    </message>
-</context>
-<context>
-    <name>ImageLoader</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Галерея</translation>
-    </message>
 </context>
 <context>
     <name>ImgDeleteDialog</name>
@@ -350,9 +267,21 @@
         <source>Are you sure you want to delete this photo from the album?</source>
         <translation>Вы уверены, что хотите удалить эту фотографию из альбома?</translation>
     </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n photos from albums?</source>
+        <translation><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform></translation>
+    </message>
     <message>
-        <source>Are you sure you want to delete %1 photos from albums?</source>
-        <translation>Вы уверены, что хотите удалить %1 фото из альбомов?</translation>
+        <source>Are you sure you want to delete this video from the album?</source>
+        <translation>Вы уверены, что хотите удалить это видео из альбома?</translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n videos from albums?</source>
+        <translation><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>Are you sure you want to delete %n items from albums?</source>
+        <translation><numerusform>Вы уверены, что хотите удалить %n элемент из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform></translation>
     </message>
 </context>
 <context>
@@ -370,37 +299,46 @@
         <translation>Информация о фотографии</translation>
     </message>
 </context>
-<context>
-    <name>ImportImagesThread</name>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Галерея</translation>
-    </message>
-</context>
 <context>
     <name>ImportTimeLineView</name>
     <message>
         <source>Import</source>
         <translation>Импортировать</translation>
     </message>
+    <message>
+        <source>1 photo</source>
+        <translation>1 фото</translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation>1 видео</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items</source>
+        <translation><numerusform>%n элемент</numerusform><numerusform>%n элементов</numerusform><numerusform>%n элементов</numerusform><numerusform>%n элементов</numerusform></translation>
+    </message>
 </context>
 <context>
     <name>ImportView</name>
     <message>
-        <source>All Photos</source>
-        <translation>Все фотографии</translation>
+        <source>Import Photos and Videos</source>
+        <translation>Импорт фото и видео</translation>
     </message>
     <message>
-        <source>Import Photos</source>
-        <translation>Импортировать Фотографии</translation>
+        <source>Or drag them here</source>
+        <translation>Или перетащите их сюда</translation>
     </message>
     <message>
-        <source>Or drag photos here</source>
-        <translation>Или перетащите фотографии сюда</translation>
-    </message>
-    <message>
-        <source>Gallery</source>
-        <translation type="vanished">Галерея</translation>
+        <source>All photos and videos</source>
+        <translation>Все фото и видео</translation>
     </message>
 </context>
 <context>
@@ -421,10 +359,6 @@
         <source>Delete</source>
         <translation>Удалить</translation>
     </message>
-    <message>
-        <source>Unnamed</source>
-        <translation type="vanished">Без названия</translation>
-    </message>
     <message>
         <source>Device</source>
         <translation>Устройство</translation>
@@ -445,15 +379,15 @@
 <context>
     <name>LockWidget</name>
     <message>
-        <source>You have no permission to view the image</source>
-        <translation>У вас нет разрешения на просмотр изображения</translation>
+        <source>You have no permission to view the file</source>
+        <translation>У Вас нет разрешения на просмотр файла</translation>
     </message>
 </context>
 <context>
     <name>Main</name>
     <message>
-        <source>Album is a fashion photo manager for viewing and organizing pictures.</source>
-        <translation>Альбом - это красивое и современное приложение для просмотра и организации фотографий.</translation>
+        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
+        <translation>Альбом - это модный менеджер для просмотра и организации фото и видео.</translation>
     </message>
 </context>
 <context>
@@ -550,14 +484,6 @@
         <source>Albums</source>
         <translation>Альбомы</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation type="vanished">%1 фото(графий)</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Информация о фотографии</translation>
-    </message>
     <message>
         <source>Exit fullscreen/slideshow</source>
         <translation>Выход из полноэкранного режиме / слайд-шоу</translation>
@@ -570,22 +496,10 @@
         <source>View</source>
         <translation>Показать</translation>
     </message>
-    <message>
-        <source>Export</source>
-        <translation>Экспорт</translation>
-    </message>
-    <message>
-        <source>Import</source>
-        <translation>Импортировать</translation>
-    </message>
     <message>
         <source>Select all</source>
         <translation>Выбрать все</translation>
     </message>
-    <message>
-        <source>Delete photo/album</source>
-        <translation>Удалить фото/альбом</translation>
-    </message>
     <message>
         <source>Zoom in</source>
         <translation>Приблизить</translation>
@@ -610,37 +524,41 @@
         <source>Settings</source>
         <translation>Параметры</translation>
     </message>
-    <message>
-        <source>Some photos have not been imported</source>
-        <translation type="vanished">Некоторые фотографии не были импортированы</translation>
-    </message>
     <message>
         <source>Import photos</source>
         <translation>Импорт фотографий</translation>
     </message>
-    <message>
-        <source>Import Photos</source>
-        <translation>Импортировать Фотографии</translation>
-    </message>
-    <message>
-        <source>%1/%2 photos imported</source>
-        <translation>%1/%2 фото импортировано</translation>
-    </message>
-    <message>
-        <source>%1 photos imported, %2 photos failed</source>
-        <translation>%1 фото импортировано, %2 фото не удалось импортировать</translation>
-    </message>
-    <message>
-        <source>%1/%2 photos deleted</source>
-        <translation>%1/%2 фото удалено</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Импортирование...</translation>
     </message>
     <message>
-        <source>Photos already exist</source>
-        <translation type="unfinished"/>
+        <source>All photos and videos</source>
+        <translation>Все фото и видео</translation>
+    </message>
+    <message>
+        <source>Import Photos and Videos</source>
+        <translation>Импорт фото и видео</translation>
+    </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Ни фото, ни видео не найдено</translation>
+    </message>
+    <message>
+        <source>Export photos</source>
+        <translation>Экспорт фото</translation>
+    </message>
+    <message>
+        <source>Import photos/videos</source>
+        <translation>Импорт фото/видео</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Удалить</translation>
+    </message>
+    <message>
+        <source>Photo/Video info</source>
+        <translation>Информация о фото/видео</translation>
     </message>
 </context>
 <context>
@@ -731,78 +649,10 @@
     </message>
 </context>
 <context>
-    <name>MountThumbnailListView</name>
+    <name>NoResultWidget</name>
     <message>
-        <source>Photo info</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>View</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Restore</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Add to album</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation type="unfinished"/>
+        <source>No results</source>
+        <translation>Нет результатов</translation>
     </message>
 </context>
 <context>
@@ -812,56 +662,6 @@
         <translation>Системный диск</translation>
     </message>
 </context>
-<context>
-    <name>PrintOptionsPage</name>
-    <message>
-        <source>No scaling</source>
-        <translation type="vanished">Без масштабирования</translation>
-    </message>
-    <message>
-        <source>Fit page to image</source>
-        <translation type="vanished">Подогнать страницу к изображению</translation>
-    </message>
-    <message>
-        <source>Fit image to page</source>
-        <translation type="vanished">Подогнать изображение к странице</translation>
-    </message>
-    <message>
-        <source>Scale to:</source>
-        <translation type="vanished">Масштабировать до:</translation>
-    </message>
-    <message>
-        <source>Millimeters</source>
-        <translation type="vanished">Миллиметров</translation>
-    </message>
-    <message>
-        <source>Centimeters</source>
-        <translation type="vanished">Сантиметров</translation>
-    </message>
-    <message>
-        <source>Inches</source>
-        <translation type="vanished">Дюймов</translation>
-    </message>
-    <message>
-        <source>Image Position</source>
-        <translation type="vanished">Положение изображения</translation>
-    </message>
-    <message>
-        <source>Scaling</source>
-        <translation type="vanished">Масштабирование</translation>
-    </message>
-    <message>
-        <source>Image Settings</source>
-        <translation type="vanished">Параметры изображения</translation>
-    </message>
-</context>
-<context>
-    <name>PrintPreviewDialog</name>
-    <message>
-        <source>Image Settings</source>
-        <translation type="vanished">Параметры изображения</translation>
-    </message>
-</context>
 <context>
     <name>QObject</name>
     <message>
@@ -876,22 +676,6 @@
         <source>%1/%2/%3</source>
         <translation>%1/%2/%3</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 фото(графий)</translation>
-    </message>
-    <message>
-        <source>%1 photo(s) selected</source>
-        <translation>% 1 фото(графий) выбрано</translation>
-    </message>
-    <message>
-        <source>%1/%2/%3 %4</source>
-        <translation type="vanished">%1/%2/%3 %4</translation>
-    </message>
-    <message>
-        <source>Import on </source>
-        <translation type="vanished">Импорт на</translation>
-    </message>
     <message>
         <source>Imported on</source>
         <translation>Импортировано на</translation>
@@ -904,6 +688,98 @@
         <source>Imported on </source>
         <translation>Импортировано на</translation>
     </message>
+    <message>
+        <source>Select All</source>
+        <translation>Выбрать всё</translation>
+    </message>
+    <message>
+        <source>Unselect All</source>
+        <translation>Снять выделение</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Отмена</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation>Восстановить</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Удалить</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Всё</translation>
+    </message>
+    <message>
+        <source>Photos</source>
+        <translation>Фотографии</translation>
+    </message>
+    <message>
+        <source>Videos</source>
+        <translation>Видео</translation>
+    </message>
+    <message>
+        <source>No results</source>
+        <translation>Нет результатов</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation>Добавить в избранное</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation>Повернуть против часовой стрелки</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation>Повернуть по часовой стрелке</translation>
+    </message>
+    <message>
+        <source>Importing...</source>
+        <translation>Импортирование...</translation>
+    </message>
+    <message>
+        <source>%1/%2 items imported</source>
+        <translation>%1/%2 элементов импортирован (ы)</translation>
+    </message>
+    <message>
+        <source>%1/%2 items deleted</source>
+        <translation>%1/%2 элементов удален (ы)</translation>
+    </message>
+    <message>
+        <source>%1 items imported, %2 items failed</source>
+        <translation>%1 элемент (ов) импортирован (о), %2 элемент (ов) не удалось импортировать</translation>
+    </message>
+    <message>
+        <source>1 photo selected</source>
+        <translation>1 фото выбрано</translation>
+    </message>
+    <message>
+        <source>1 video selected</source>
+        <translation>1 видео выбрано</translation>
+    </message>
+    <message>
+        <source>The photo/video already exists</source>
+        <translation>Фото/видео уже существует</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos selected</source>
+        <translation><numerusform>%n фото выбрано</numerusform><numerusform>%n фото выбраны</numerusform><numerusform>%n фото выбраны</numerusform><numerusform>%n фото выбраны</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos selected</source>
+        <translation><numerusform>%n видео выбрано</numerusform><numerusform>%n видео выбраны</numerusform><numerusform>%n видео выбраны</numerusform><numerusform>%n видео выбраны</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items selected</source>
+        <translation><numerusform>%n элемент выбран</numerusform><numerusform>%n элементов выбрано</numerusform><numerusform>%n элементов выбрано</numerusform><numerusform>%n элементов выбрано</numerusform></translation>
+    </message>
+    <message>
+        <source>%1 items imported, %2 items exist already</source>
+        <translation>%1 элемент (ов) импортирован (о), %2 элемент (ов) не удалось импортировать</translation>
+    </message>
 </context>
 <context>
     <name>SearchView</name>
@@ -915,14 +791,30 @@
         <source>Slide Show</source>
         <translation>Cлайд-шоу</translation>
     </message>
-    <message>
-        <source>%1 photo(s) found</source>
-        <translation>%1 найдено фото(графий)</translation>
-    </message>
     <message>
         <source>Search results</source>
         <translation>Результаты поиска</translation>
     </message>
+    <message>
+        <source>1 photo found</source>
+        <translation>Найдено 1 фото</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos found</source>
+        <translation><numerusform>Найдено %n видео</numerusform><numerusform>Найдены %n видео</numerusform><numerusform>Найдены %n видео</numerusform><numerusform>Найдены %n видео</numerusform></translation>
+    </message>
+    <message>
+        <source>1 video found</source>
+        <translation>Найдено 1 видео</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items found</source>
+        <translation><numerusform>Найден %n элемент</numerusform><numerusform>Найдено %n элементов</numerusform><numerusform>Найдено %n элементов</numerusform><numerusform>Найдено %n элементов</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos found</source>
+        <translation><numerusform>Найдено %n фото</numerusform><numerusform>Найдено %n фото</numerusform><numerusform>Найдено %n фото</numerusform><numerusform>Найдено %n фото</numerusform></translation>
+    </message>
 </context>
 <context>
     <name>SlideShowBottomBar</name>
@@ -950,12 +842,28 @@
 <context>
     <name>StatusBar</name>
     <message>
-        <source>Importing photos: &apos;%1&apos;</source>
-        <translation>Импортируются фотографии: &apos;%1&apos;</translation>
+        <source>1 photo</source>
+        <translation>1 фото</translation>
     </message>
     <message>
-        <source>Exporting photos: &apos;%1&apos;</source>
-        <translation>Экспортируются фотографии: &apos;%1&apos;</translation>
+        <source>1 video</source>
+        <translation>1 видео</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform></translation>
+    </message>
+    <message>
+        <source>Importing: %1</source>
+        <translation>Импортировано: %1</translation>
+    </message>
+    <message>
+        <source>Exporting: %1</source>
+        <translation>Экспортировано: %1</translation>
     </message>
 </context>
 <context>
@@ -1075,6 +983,14 @@
         <source>Print</source>
         <translation>Печать</translation>
     </message>
+    <message>
+        <source>Video info</source>
+        <translation>Информация о  видео</translation>
+    </message>
+    <message>
+        <source>days</source>
+        <translation>дней</translation>
+    </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
@@ -1087,6 +1003,120 @@
         <translation>Фотографии не найдены</translation>
     </message>
 </context>
+<context>
+    <name>TimeLineView</name>
+    <message>
+        <source>1 photo</source>
+        <translation>1 фото</translation>
+    </message>
+    <message>
+        <source>1 video</source>
+        <translation>1 видео</translation>
+    </message>
+    <message numerus="yes">
+        <source>%n photos</source>
+        <translation><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n videos</source>
+        <translation><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n items</source>
+        <translation><numerusform>%n элемент</numerusform><numerusform>%n элементов</numerusform><numerusform>%n элементов</numerusform><numerusform>%n элементов</numerusform></translation>
+    </message>
+</context>
+<context>
+    <name>VideoInfoDialog</name>
+    <message>
+        <source>Basic info</source>
+        <translation>Основная информация</translation>
+    </message>
+    <message>
+        <source>Codec info</source>
+        <translation>Информация о кодеке</translation>
+    </message>
+    <message>
+        <source>Audio info</source>
+        <translation>Информация об аудио</translation>
+    </message>
+    <message>
+        <source>Video CodecID</source>
+        <translation>Видео КодекИД</translation>
+    </message>
+    <message>
+        <source>Video CodeRate</source>
+        <translation>Битрейт</translation>
+    </message>
+    <message>
+        <source>FPS</source>
+        <translation>Кадров в секунду</translation>
+    </message>
+    <message>
+        <source>Proportion</source>
+        <translation>Соотношение сторон</translation>
+    </message>
+    <message>
+        <source>Resolution</source>
+        <translation>Разрешение</translation>
+    </message>
+    <message>
+        <source>Audio CodecID</source>
+        <translation>Аудио КодекИД</translation>
+    </message>
+    <message>
+        <source>Audio CodeRate</source>
+        <translation>Битрейт</translation>
+    </message>
+    <message>
+        <source>Audio digit</source>
+        <translation>Цифровое аудио</translation>
+    </message>
+    <message>
+        <source>Channels</source>
+        <translation>Каналы</translation>
+    </message>
+    <message>
+        <source>Channel</source>
+        <translation>Канал</translation>
+    </message>
+    <message>
+        <source>Sampling</source>
+        <translation>Сэмплирование</translation>
+    </message>
+    <message>
+        <source>Video name</source>
+        <translation>Название видео</translation>
+    </message>
+    <message>
+        <source>Date modified</source>
+        <translation>Дата изменения</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation>Тип</translation>
+    </message>
+    <message>
+        <source>File size</source>
+        <translation>Размер файла</translation>
+    </message>
+    <message>
+        <source>Duration</source>
+        <translation>Продолжительность</translation>
+    </message>
+    <message>
+        <source>Path</source>
+        <translation>Путь</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation>Информация о  видео</translation>
+    </message>
+    <message>
+        <source>Date captured</source>
+        <translation>Дата создания</translation>
+    </message>
+</context>
 <context>
     <name>ViewPanel</name>
     <message>
